AccessLogTryAndRecoverApi class

Constructors

AccessLogTryAndRecoverApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAccessLog(AccessLog entity) → Future<AccessLog>
filterAccessLogsBy(FilterOptions<AccessLog> filter) → Future<PaginatedListIterator<AccessLog>>
filterAccessLogsBySorted(SortableFilterOptions<AccessLog> filter) → Future<PaginatedListIterator<AccessLog>>
getAccessLog(String entityId) → Future<AccessLog?>
getAccessLogs(List<String> entityIds) → Future<List<AccessLog>>
modifyAccessLog(AccessLog entity) → Future<AccessLog>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String delegateId, AccessLog accessLog, {AccessLogShareOptions? options}) → Future<AccessLog>
shareWithMany(AccessLog accessLog, Map<String, AccessLogShareOptions> delegates) → Future<AccessLog>
toString() → String
A string representation of this object.
inherited
undeleteAccessLog(AccessLog accessLog) → Future<AccessLog>
undeleteAccessLogById(String id, String rev) → Future<AccessLog>

Operators

operator ==(Object other) → bool
The equality operator.
inherited