CodeApi class

Constructors

CodeApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createCode(Code c) → Future<Code>
createCodes(List<Code> codeBatch) → Future<List<Code>>
createCodesInGroup(String groupId, List<Code> codeBatch) → Future<List<Code>>
filterCodesBy(BaseFilterOptions<Code> filter) → Future<PaginatedListIterator<Code>>
filterCodesBySorted(BaseSortableFilterOptions<Code> filter) → Future<PaginatedListIterator<Code>>
getCode(String codeId) → Future<Code?>
getCodeByRegionLanguageTypeLabel(String region, String label, String type, String? languages) → Future<Code?>
getCodes(List<String> codeIds) → Future<List<Code>>
getCodesInGroup(String groupId, List<String> codeIds) → Future<List<Code>>
getCodeWithParts(String type, String code, String version) → Future<Code?>
importCodes(String codeType) → Future<void>
isCodeValid(String type, String code, String? version) → Future<BooleanResponse>
listCodesByRegionTypeCodeVersion(String region, {String? type, String? code, String? version}) → Future<List<Code>>
listCodeTypesBy({String? region, String? type}) → Future<List<String>>
listTagTypesBy({String? region, String? type}) → Future<List<String>>
matchCodesBy(BaseFilterOptions<Code> filter) → Future<List<String>>
matchCodesBySorted(BaseSortableFilterOptions<Code> filter) → Future<List<String>>
modifyCode(Code codeDto) → Future<Code>
modifyCodes(List<Code> codeBatch) → Future<List<Code>>
modifyCodesInGroup(String groupId, List<Code> codeBatch) → Future<List<Code>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited