ContactEncryptedApi class

Constructors

ContactEncryptedApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createContact(EncryptedContact entity) → Future<EncryptedContact>
createContacts(List<EncryptedContact> entities) → Future<List<EncryptedContact>>
filterContactsBy(FilterOptions<Contact> filter) → Future<PaginatedListIterator<EncryptedContact>>
filterContactsBySorted(SortableFilterOptions<Contact> filter) → Future<PaginatedListIterator<EncryptedContact>>
filterServicesBy(FilterOptions<Service> filter) → Future<PaginatedListIterator<EncryptedService>>
filterServicesBySorted(SortableFilterOptions<Service> filter) → Future<PaginatedListIterator<EncryptedService>>
getContact(String entityId) → Future<EncryptedContact?>
getContacts(List<String> entityIds) → Future<List<EncryptedContact>>
getService(String serviceId) → Future<EncryptedService>
getServices(List<String> entityIds) → Future<List<EncryptedService>>
modifyContact(EncryptedContact entity) → Future<EncryptedContact>
modifyContacts(List<EncryptedContact> entities) → Future<List<EncryptedContact>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String delegateId, EncryptedContact contact, {ContactShareOptions? options}) → Future<EncryptedContact>
shareWithMany(EncryptedContact contact, Map<String, ContactShareOptions> delegates) → Future<EncryptedContact>
toString() → String
A string representation of this object.
inherited
undeleteContact(Contact contact) → Future<EncryptedContact>
undeleteContactById(String id, String rev) → Future<EncryptedContact>

Operators

operator ==(Object other) → bool
The equality operator.
inherited