DocumentApi class

Constructors

DocumentApi(String _sdkId, Object _dartSdk)

Properties

encrypted → DocumentEncryptedApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover → DocumentTryAndRecoverApi
final

Methods

createDelegationDeAnonymizationMetadata(Document entity, Set<String> delegates) → Future<void>
createDocument(DecryptedDocument entity) → Future<DecryptedDocument>
decrypt(EncryptedDocument document) → Future<DecryptedDocument>
decryptPatientIdOf(Document document) → Future<Set<String>>
deleteDocument(Document document) → Future<DocIdentifier>
deleteDocumentById(String entityId, String rev) → Future<DocIdentifier>
deleteDocuments(List<Document> documents) → Future<List<DocIdentifier>>
deleteDocumentsByIds(List<StoredDocumentIdentifier> entityIds) → Future<List<DocIdentifier>>
deleteMainAttachment(String entityId, String rev) → Future<EncryptedDocument>
deleteSecondaryAttachment(String documentId, String key, String rev) → Future<EncryptedDocument>
encryptAndSetMainAttachment(Document document, List<String>? utis, Uint8List attachment) → Future<EncryptedDocument>
encryptAndSetSecondaryAttachment(Document document, String key, List<String>? utis, Uint8List attachment) → Future<EncryptedDocument>
filterDocumentsBy(FilterOptions<Document> filter) → Future<PaginatedListIterator<DecryptedDocument>>
filterDocumentsBySorted(SortableFilterOptions<Document> filter) → Future<PaginatedListIterator<DecryptedDocument>>
getAndDecryptMainAttachment(Document document, {bool decryptedAttachmentValidator(Uint8List)?}) → Future<Uint8List>
getAndDecryptSecondaryAttachment(Document document, String key, {bool decryptedAttachmentValidator(Uint8List)?}) → Future<Uint8List>
getAndTryDecryptMainAttachment(Document document, {bool decryptedAttachmentValidator(Uint8List)?}) → Future<Uint8List?>
getDocument(String entityId) → Future<DecryptedDocument?>
getDocuments(List<String> entityIds) → Future<List<DecryptedDocument>>
getEncryptionKeysOf(Document document) → Future<Set<String>>
getRawMainAttachment(String documentId) → Future<Uint8List>
getRawSecondaryAttachment(String documentId, String key) → Future<Uint8List>
hasWriteAccess(Document document) → Future<bool>
matchDocumentsBy(FilterOptions<Document> filter) → Future<List<String>>
matchDocumentsBySorted(SortableFilterOptions<Document> filter) → Future<List<String>>
modifyDocument(DecryptedDocument entity) → Future<DecryptedDocument>
modifyDocuments(List<DecryptedDocument> entities) → Future<List<DecryptedDocument>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeDocument(Document document) → Future<void>
purgeDocumentById(String id, String rev) → Future<void>
setRawMainAttachment(String documentId, String rev, List<String>? utis, Uint8List attachment, bool encrypted) → Future<EncryptedDocument>
setRawSecondaryAttachment(String documentId, String key, String rev, List<String>? utis, Uint8List attachment, bool encrypted) → Future<EncryptedDocument>
shareWith(String delegateId, DecryptedDocument document, {DocumentShareOptions? options}) → Future<DecryptedDocument>
shareWithMany(DecryptedDocument document, Map<String, DocumentShareOptions> delegates) → Future<DecryptedDocument>
toString() → String
A string representation of this object.
inherited
tryDecrypt(EncryptedDocument document) → Future<Document>
tryDecryptAttachment(Document document, Uint8List encryptedAttachment, {bool decryptedAttachmentValidator(Uint8List)?}) → Future<Uint8List?>
undeleteDocument(Document document) → Future<DecryptedDocument>
undeleteDocumentById(String id, String rev) → Future<DecryptedDocument>
withEncryptionMetadata(DecryptedDocument? base, Message? message, {User? user, Map<String, AccessLevel> delegates = const {}, SecretIdUseOption secretId = SecretIdUseOption.UseAnySharedWithParent}) → Future<DecryptedDocument>

Operators

operator ==(Object other) → bool
The equality operator.
inherited