DocumentTryAndRecoverApi class

Constructors

DocumentTryAndRecoverApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDocument(Document entity) → Future<Document>
filterDocumentsBy(FilterOptions<Document> filter) → Future<PaginatedListIterator<Document>>
filterDocumentsBySorted(SortableFilterOptions<Document> filter) → Future<PaginatedListIterator<Document>>
getDocument(String entityId) → Future<Document?>
getDocuments(List<String> entityIds) → Future<List<Document>>
modifyDocument(Document entity) → Future<Document>
modifyDocuments(List<Document> entities) → Future<List<Document>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String delegateId, Document document, {DocumentShareOptions? options}) → Future<Document>
shareWithMany(Document document, Map<String, DocumentShareOptions> delegates) → Future<Document>
toString() → String
A string representation of this object.
inherited
undeleteDocument(Document document) → Future<Document>
undeleteDocumentById(String id, String rev) → Future<Document>

Operators

operator ==(Object other) → bool
The equality operator.
inherited