FormApi class

Constructors

FormApi(String _sdkId, Object _dartSdk)

Properties

encrypted → FormEncryptedApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover → FormTryAndRecoverApi
final

Methods

createDelegationDeAnonymizationMetadata(Form entity, Set<String> delegates) → Future<void>
createForm(DecryptedForm entity) → Future<DecryptedForm>
createForms(List<DecryptedForm> entities) → Future<List<DecryptedForm>>
createFormTemplate(FormTemplate formTemplate) → Future<FormTemplate>
decrypt(EncryptedForm form) → Future<DecryptedForm>
decryptPatientIdOf(Form form) → Future<Set<String>>
deleteForm(Form form) → Future<DocIdentifier>
deleteFormById(String entityId, String rev) → Future<DocIdentifier>
deleteForms(List<Form> forms) → Future<List<DocIdentifier>>
deleteFormsByIds(List<StoredDocumentIdentifier> entityIds) → Future<List<DocIdentifier>>
deleteFormTemplate(String formTemplateId) → Future<DocIdentifier>
filterFormsBy(FilterOptions<Form> filter) → Future<PaginatedListIterator<DecryptedForm>>
filterFormsBySorted(SortableFilterOptions<Form> filter) → Future<PaginatedListIterator<DecryptedForm>>
getEncryptionKeysOf(Form form) → Future<Set<String>>
getForm(String entityId) → Future<DecryptedForm?>
getForms(List<String> entityIds) → Future<List<DecryptedForm>>
getFormTemplate(String formTemplateId, {bool? raw}) → Future<FormTemplate>
getLatestFormByLogicalUuid(String logicalUuid) → Future<DecryptedForm>
getLatestFormByUniqueId(String uniqueId) → Future<DecryptedForm>
hasWriteAccess(Form form) → Future<bool>
matchFormsBy(FilterOptions<Form> filter) → Future<List<String>>
matchFormsBySorted(SortableFilterOptions<Form> filter) → Future<List<String>>
modifyForm(DecryptedForm entity) → Future<DecryptedForm>
modifyForms(List<DecryptedForm> entities) → Future<List<DecryptedForm>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeForm(Form form) → Future<void>
purgeFormById(String id, String rev) → Future<void>
setTemplateAttachment(String formTemplateId, Uint8List payload) → Future<String>
shareWith(String delegateId, DecryptedForm form, {FormShareOptions? options}) → Future<DecryptedForm>
shareWithMany(DecryptedForm form, Map<String, FormShareOptions> delegates) → Future<DecryptedForm>
toString() → String
A string representation of this object.
inherited
tryDecrypt(EncryptedForm form) → Future<Form>
undeleteForm(Form form) → Future<DecryptedForm>
undeleteFormById(String id, String rev) → Future<DecryptedForm>
updateFormTemplate(FormTemplate formTemplate) → Future<FormTemplate>
withEncryptionMetadata(DecryptedForm? base, Patient patient, {User? user, Map<String, AccessLevel> delegates = const {}, SecretIdUseOption secretId = SecretIdUseOption.UseAnySharedWithParent}) → Future<DecryptedForm>

Operators

operator ==(Object other) → bool
The equality operator.
inherited