FormTryAndRecoverApi class

Constructors

FormTryAndRecoverApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createForm(Form entity) → Future<Form>
createForms(List<Form> entities) → Future<List<Form>>
filterFormsBy(FilterOptions<Form> filter) → Future<PaginatedListIterator<Form>>
filterFormsBySorted(SortableFilterOptions<Form> filter) → Future<PaginatedListIterator<Form>>
getForm(String entityId) → Future<Form?>
getForms(List<String> entityIds) → Future<List<Form>>
getLatestFormByLogicalUuid(String logicalUuid) → Future<Form>
getLatestFormByUniqueId(String uniqueId) → Future<Form>
modifyForm(Form entity) → Future<Form>
modifyForms(List<Form> entities) → Future<List<Form>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String delegateId, Form form, {FormShareOptions? options}) → Future<Form>
shareWithMany(Form form, Map<String, FormShareOptions> delegates) → Future<Form>
toString() → String
A string representation of this object.
inherited
undeleteForm(Form form) → Future<Form>
undeleteFormById(String id, String rev) → Future<Form>

Operators

operator ==(Object other) → bool
The equality operator.
inherited