FormBasicApi class

Constructors

FormBasicApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createForm(EncryptedForm entity) → Future<EncryptedForm>
createForms(List<EncryptedForm> entities) → Future<List<EncryptedForm>>
createFormTemplate(FormTemplate formTemplate) → Future<FormTemplate>
deleteForm(Form form) → Future<DocIdentifier>
deleteFormById(String entityId, String rev) → Future<DocIdentifier>
deleteForms(List<Form> forms) → Future<List<DocIdentifier>>
deleteFormsByIds(List<StoredDocumentIdentifier> entityIds) → Future<List<DocIdentifier>>
deleteFormTemplate(String formTemplateId) → Future<DocIdentifier>
filterFormsBy(BaseFilterOptions<Form> filter) → Future<PaginatedListIterator<EncryptedForm>>
filterFormsBySorted(BaseSortableFilterOptions<Form> filter) → Future<PaginatedListIterator<EncryptedForm>>
getForm(String entityId) → Future<EncryptedForm?>
getForms(List<String> entityIds) → Future<List<EncryptedForm>>
getFormTemplate(String formTemplateId, {bool? raw}) → Future<FormTemplate>
getLatestFormByLogicalUuid(String logicalUuid) → Future<EncryptedForm>
getLatestFormByUniqueId(String uniqueId) → Future<EncryptedForm>
matchFormsBy(BaseFilterOptions<Form> filter) → Future<List<String>>
matchFormsBySorted(BaseSortableFilterOptions<Form> filter) → Future<List<String>>
modifyForm(EncryptedForm entity) → Future<EncryptedForm>
modifyForms(List<EncryptedForm> entities) → Future<List<EncryptedForm>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeForm(Form form) → Future<void>
purgeFormById(String id, String rev) → Future<void>
setTemplateAttachment(String formTemplateId, Uint8List payload) → Future<String>
toString() → String
A string representation of this object.
inherited
undeleteForm(Form form) → Future<EncryptedForm>
undeleteFormById(String id, String rev) → Future<EncryptedForm>
updateFormTemplate(FormTemplate formTemplate) → Future<FormTemplate>

Operators

operator ==(Object other) → bool
The equality operator.
inherited