HealthElementInGroupApi class

Constructors

HealthElementInGroupApi(String _sdkId, Object _dartSdk)

Properties

encrypted → HealthElementInGroupEncryptedApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover → HealthElementInGroupTryAndRecoverApi
final

Methods

createDelegationDeAnonymizationMetadata(GroupScoped<HealthElement> entity, Set<EntityReferenceInGroup> delegates) → Future<void>
createHealthElement(GroupScoped<DecryptedHealthElement> entity) → Future<GroupScoped<DecryptedHealthElement>>
decrypt(List<GroupScoped<EncryptedHealthElement>> healthElements) → Future<List<GroupScoped<DecryptedHealthElement>>>
decryptPatientIdOf(GroupScoped<HealthElement> healthElement) → Future<Set<EntityReferenceInGroup>>
encryptOrValidate(List<GroupScoped<HealthElement>> healthElements) → Future<List<GroupScoped<EncryptedHealthElement>>>
getEncryptionKeysOf(GroupScoped<HealthElement> healthElement) → Future<Set<String>>
getHealthElement(String groupId, String entityId) → Future<GroupScoped<DecryptedHealthElement>?>
hasWriteAccess(GroupScoped<HealthElement> healthElement) → Future<bool>
modifyHealthElement(GroupScoped<DecryptedHealthElement> entity) → Future<GroupScoped<DecryptedHealthElement>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(EntityReferenceInGroup delegate, GroupScoped<DecryptedHealthElement> healthElement, {HealthElementShareOptions? options}) → Future<GroupScoped<DecryptedHealthElement>>
shareWithMany(GroupScoped<DecryptedHealthElement> healthElement, Map<EntityReferenceInGroup, HealthElementShareOptions> delegates) → Future<GroupScoped<DecryptedHealthElement>>
toString() → String
A string representation of this object.
inherited
tryDecrypt(List<GroupScoped<EncryptedHealthElement>> healthElements) → Future<List<GroupScoped<HealthElement>>>
withEncryptionMetadata(String entityGroupId, DecryptedHealthElement? base, GroupScoped<Patient> patient, {User? user, Map<EntityReferenceInGroup, AccessLevel> delegates = const {}, SecretIdUseOption secretId = SecretIdUseOption.UseAnySharedWithParent}) → Future<GroupScoped<DecryptedHealthElement>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited