InvoiceApi class

Constructors

InvoiceApi(String _sdkId, Object _dartSdk)

Properties

encrypted → InvoiceEncryptedApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover → InvoiceTryAndRecoverApi
final

Methods

appendCodes(String userId, String type, String sentMediumType, String secretFKeys, List<EncryptedInvoicingCode> invoicingCodes, {String? insuranceId, String? invoiceId, int? gracePeriod}) → Future<List<DecryptedInvoice>>
createDelegationDeAnonymizationMetadata(Invoice entity, Set<String> delegates) → Future<void>
createInvoice(DecryptedInvoice entity, String? prefix) → Future<DecryptedInvoice>
createInvoices(List<DecryptedInvoice> entities) → Future<List<DecryptedInvoice>>
decrypt(EncryptedInvoice invoice) → Future<DecryptedInvoice>
decryptPatientIdOf(Invoice invoice) → Future<Set<String>>
deleteInvoice(String entityId) → Future<DocIdentifier>
getEncryptionKeysOf(Invoice invoice) → Future<Set<String>>
getInvoice(String entityId) → Future<DecryptedInvoice?>
getInvoices(List<String> entityIds) → Future<List<DecryptedInvoice>>
getTarificationsCodesOccurrences(int minOccurrence) → Future<List<LabelledOccurence>>
hasWriteAccess(Invoice invoice) → Future<bool>
listInvoicesByContactIds(List<String> contactIds) → Future<List<DecryptedInvoice>>
listInvoicesByHcPartyAndGroupId(String hcPartyId, String groupId) → Future<List<DecryptedInvoice>>
listInvoicesByHcpartySendingModeStatusDate(String hcPartyId, String sendingMode, String status, int from, int to) → Future<List<DecryptedInvoice>>
listInvoicesByHcPartySentMediumTypeInvoiceTypeSentDate(String hcPartyId, MediumType sentMediumType, InvoiceType invoiceType, bool sent, {int? from, int? to}) → Future<List<DecryptedInvoice>>
listInvoicesByIds(List<String> ids) → Future<List<DecryptedInvoice>>
listInvoicesByRecipientsIds(List<String> recipientsIds) → Future<List<DecryptedInvoice>>
listToInsurances(List<String> userIds) → Future<List<DecryptedInvoice>>
listToInsurancesUnsent(List<String> userIds) → Future<List<DecryptedInvoice>>
listToPatients(String hcPartyId) → Future<List<DecryptedInvoice>>
listToPatientsUnsent(String? hcPartyId) → Future<List<DecryptedInvoice>>
mergeTo(String invoiceId, List<String> ids) → Future<DecryptedInvoice>
modifyInvoice(DecryptedInvoice entity) → Future<DecryptedInvoice>
modifyInvoices(List<DecryptedInvoice> entities) → Future<List<DecryptedInvoice>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassignInvoice(DecryptedInvoice invoice) → Future<DecryptedInvoice>
removeCodes(String userId, String serviceId, String secretFKeys, List<String> tarificationIds) → Future<List<DecryptedInvoice>>
shareWith(String delegateId, DecryptedInvoice invoice, {InvoiceShareOptions? options}) → Future<DecryptedInvoice>
shareWithMany(DecryptedInvoice invoice, Map<String, InvoiceShareOptions> delegates) → Future<DecryptedInvoice>
toString() → String
A string representation of this object.
inherited
tryDecrypt(EncryptedInvoice invoice) → Future<Invoice>
validate(String invoiceId, String scheme, String forcedValue) → Future<DecryptedInvoice>
withEncryptionMetadata(DecryptedInvoice? base, Patient? patient, {User? user, Map<String, AccessLevel> delegates = const {}, SecretIdUseOption secretId = SecretIdUseOption.UseAnySharedWithParent}) → Future<DecryptedInvoice>

Operators

operator ==(Object other) → bool
The equality operator.
inherited