InvoiceEncryptedApi class

Constructors

InvoiceEncryptedApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendCodes(String userId, String type, String sentMediumType, String secretFKeys, List<EncryptedInvoicingCode> invoicingCodes, {String? insuranceId, String? invoiceId, int? gracePeriod}) → Future<List<EncryptedInvoice>>
getInvoice(String entityId) → Future<EncryptedInvoice?>
getInvoices(List<String> entityIds) → Future<List<EncryptedInvoice>>
listInvoicesByContactIds(List<String> contactIds) → Future<List<EncryptedInvoice>>
listInvoicesByHcPartyAndGroupId(String hcPartyId, String groupId) → Future<List<EncryptedInvoice>>
listInvoicesByHcpartySendingModeStatusDate(String hcPartyId, String sendingMode, String status, int from, int to) → Future<List<EncryptedInvoice>>
listInvoicesByHcPartySentMediumTypeInvoiceTypeSentDate(String hcPartyId, MediumType sentMediumType, InvoiceType invoiceType, bool sent, {int? from, int? to}) → Future<List<EncryptedInvoice>>
listInvoicesByIds(List<String> ids) → Future<List<EncryptedInvoice>>
listInvoicesByRecipientsIds(List<String> recipientsIds) → Future<List<EncryptedInvoice>>
listToInsurances(List<String> userIds) → Future<List<EncryptedInvoice>>
listToInsurancesUnsent(List<String> userIds) → Future<List<EncryptedInvoice>>
listToPatients(String hcPartyId) → Future<List<EncryptedInvoice>>
listToPatientsUnsent(String? hcPartyId) → Future<List<EncryptedInvoice>>
mergeTo(String invoiceId, List<String> ids) → Future<EncryptedInvoice>
modifyInvoice(EncryptedInvoice entity) → Future<EncryptedInvoice>
modifyInvoices(List<EncryptedInvoice> entities) → Future<List<EncryptedInvoice>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassignInvoice(EncryptedInvoice invoice) → Future<EncryptedInvoice>
removeCodes(String userId, String serviceId, String secretFKeys, List<String> tarificationIds) → Future<List<EncryptedInvoice>>
shareWith(String delegateId, EncryptedInvoice invoice, {InvoiceShareOptions? options}) → Future<EncryptedInvoice>
shareWithMany(EncryptedInvoice invoice, Map<String, InvoiceShareOptions> delegates) → Future<EncryptedInvoice>
toString() → String
A string representation of this object.
inherited
validate(String invoiceId, String scheme, String forcedValue) → Future<EncryptedInvoice>

Operators

operator ==(Object other) → bool
The equality operator.
inherited