KeywordApi class

Constructors

KeywordApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createKeyword(Keyword keyword) → Future<Keyword>
deleteKeywords(List<String> keywordIds) → Future<List<DocIdentifier>>
getKeyword(String keywordId) → Future<Keyword?>
getKeywordsByUser(String userId) → Future<List<Keyword>>
modifyKeyword(Keyword keyword) → Future<Keyword>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited