MessageTryAndRecoverApi class

Constructors

MessageTryAndRecoverApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createMessage(Message entity) → Future<Message>
createMessageInTopic(Message entity) → Future<Message>
filterMessagesBy(FilterOptions<Message> filter) → Future<PaginatedListIterator<Message>>
filterMessagesBySorted(SortableFilterOptions<Message> filter) → Future<PaginatedListIterator<Message>>
getMessage(String entityId) → Future<Message?>
getMessages(List<String> entityIds) → Future<List<Message>>
modifyMessage(Message entity) → Future<Message>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMessagesReadStatus(List<String> entityIds, int? time, bool readStatus, String? userId) → Future<List<Message>>
shareWith(String delegateId, Message message, {MessageShareOptions? options}) → Future<Message>
shareWithMany(Message message, Map<String, MessageShareOptions> delegates) → Future<Message>
toString() → String
A string representation of this object.
inherited
undeleteMessage(Message message) → Future<Message>
undeleteMessageById(String id, String rev) → Future<Message>

Operators

operator ==(Object other) → bool
The equality operator.
inherited