ReceiptEncryptedApi class

Constructors

ReceiptEncryptedApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createReceipt(EncryptedReceipt entity) → Future<EncryptedReceipt>
getReceipt(String entityId) → Future<EncryptedReceipt?>
listByReference(String reference) → Future<List<EncryptedReceipt>>
modifyReceipt(EncryptedReceipt entity) → Future<EncryptedReceipt>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String delegateId, EncryptedReceipt receipt, {ReceiptShareOptions? options}) → Future<EncryptedReceipt>
shareWithMany(EncryptedReceipt receipt, Map<String, ReceiptShareOptions> delegates) → Future<EncryptedReceipt>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited