SystemApi class

Constructors

SystemApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

evictAllFromMap(String mapName) → Future<String>
getIndexingInfo() → Future<IndexingInfo>
getIndexingInfoByGroup(String groupId) → Future<IndexingInfo>
getProcessInfo() → Future<String>
getReplicationInfo() → Future<ReplicationInfo>
getReplicatorInfo(String id) → Future<ReplicatorDocument>
getVersion() → Future<String>
isReady() → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveContactsConflicts({int? limit}) → Future<List<IdWithRev>>
resolveDocumentsConflicts({String? ids, int? limit}) → Future<List<IdWithRev>>
resolveFormsConflicts({int? limit}) → Future<List<IdWithRev>>
resolveHealthElementsConflicts({int? limit}) → Future<List<IdWithRev>>
resolveInvoicesConflicts({int? limit}) → Future<List<IdWithRev>>
resolveMessagesConflicts({int? limit}) → Future<List<IdWithRev>>
resolvePatientsConflicts({int? limit}) → Future<List<IdWithRev>>
toString() → String
A string representation of this object.
inherited
updateDesignDoc(String entityName, {bool? warmup}) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited