TopicApi class

Constructors

TopicApi(String _sdkId, Object _dartSdk)

Properties

encrypted → TopicEncryptedApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover → TopicTryAndRecoverApi
final

Methods

addParticipant(String entityId, String dataOwnerId, TopicRole topicRole) → Future<DecryptedTopic>
createDelegationDeAnonymizationMetadata(Topic entity, Set<String> delegates) → Future<void>
createTopic(DecryptedTopic entity) → Future<DecryptedTopic>
decrypt(EncryptedTopic topic) → Future<DecryptedTopic>
decryptPatientIdOf(Topic topic) → Future<Set<String>>
deleteTopic(Topic topic) → Future<DocIdentifier>
deleteTopicById(String entityId, String rev) → Future<DocIdentifier>
deleteTopics(List<Topic> topics) → Future<List<DocIdentifier>>
deleteTopicsByIds(List<StoredDocumentIdentifier> entityIds) → Future<List<DocIdentifier>>
filterTopicsBy(FilterOptions<Topic> filter) → Future<PaginatedListIterator<DecryptedTopic>>
filterTopicsBySorted(SortableFilterOptions<Topic> filter) → Future<PaginatedListIterator<DecryptedTopic>>
getEncryptionKeysOf(Topic topic) → Future<Set<String>>
getTopic(String entityId) → Future<DecryptedTopic?>
getTopics(List<String> entityIds) → Future<List<DecryptedTopic>>
hasWriteAccess(Topic topic) → Future<bool>
matchTopicsBy(FilterOptions<Topic> filter) → Future<List<String>>
matchTopicsBySorted(SortableFilterOptions<Topic> filter) → Future<List<String>>
modifyTopic(DecryptedTopic entity) → Future<DecryptedTopic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeTopic(Topic topic) → Future<void>
purgeTopicById(String id, String rev) → Future<void>
removeParticipant(String entityId, String dataOwnerId) → Future<DecryptedTopic>
shareWith(String delegateId, DecryptedTopic topic, {TopicShareOptions? options}) → Future<DecryptedTopic>
shareWithMany(DecryptedTopic topic, Map<String, TopicShareOptions> delegates) → Future<DecryptedTopic>
subscribeToEvents(Set<SubscriptionEventType> events, FilterOptions<Topic> filter, {EntitySubscriptionConfiguration? subscriptionConfig}) → Future<EntitySubscription<EncryptedTopic>>
toString() → String
A string representation of this object.
inherited
tryDecrypt(EncryptedTopic topic) → Future<Topic>
undeleteTopic(Topic topic) → Future<Topic>
undeleteTopicById(String id, String rev) → Future<DecryptedTopic>
withEncryptionMetadata(DecryptedTopic? base, Patient? patient, {User? user, Map<String, AccessLevel> delegates = const {}, SecretIdUseOption secretId = SecretIdUseOption.UseAnySharedWithParent}) → Future<DecryptedTopic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited