TopicEncryptedApi class

Constructors

TopicEncryptedApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addParticipant(String entityId, String dataOwnerId, TopicRole topicRole) → Future<EncryptedTopic>
createTopic(EncryptedTopic entity) → Future<EncryptedTopic>
filterTopicsBy(FilterOptions<Topic> filter) → Future<PaginatedListIterator<EncryptedTopic>>
filterTopicsBySorted(SortableFilterOptions<Topic> filter) → Future<PaginatedListIterator<EncryptedTopic>>
getTopic(String entityId) → Future<EncryptedTopic?>
getTopics(List<String> entityIds) → Future<List<EncryptedTopic>>
modifyTopic(EncryptedTopic entity) → Future<EncryptedTopic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeParticipant(String entityId, String dataOwnerId) → Future<EncryptedTopic>
shareWith(String delegateId, EncryptedTopic topic, {TopicShareOptions? options}) → Future<EncryptedTopic>
shareWithMany(EncryptedTopic topic, Map<String, TopicShareOptions> delegates) → Future<EncryptedTopic>
toString() → String
A string representation of this object.
inherited
undeleteTopic(Topic topic) → Future<Topic>
undeleteTopicById(String id, String rev) → Future<EncryptedTopic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited