TopicTryAndRecoverApi class

Constructors

TopicTryAndRecoverApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addParticipant(String entityId, String dataOwnerId, TopicRole topicRole) → Future<Topic>
createTopic(Topic entity) → Future<Topic>
filterTopicsBy(FilterOptions<Topic> filter) → Future<PaginatedListIterator<Topic>>
filterTopicsBySorted(SortableFilterOptions<Topic> filter) → Future<PaginatedListIterator<Topic>>
getTopic(String entityId) → Future<Topic?>
getTopics(List<String> entityIds) → Future<List<Topic>>
modifyTopic(Topic entity) → Future<Topic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeParticipant(String entityId, String dataOwnerId) → Future<Topic>
shareWith(String delegateId, Topic topic, {TopicShareOptions? options}) → Future<Topic>
shareWithMany(Topic topic, Map<String, TopicShareOptions> delegates) → Future<Topic>
toString() → String
A string representation of this object.
inherited
undeleteTopic(Topic topic) → Future<Topic>
undeleteTopicById(String id, String rev) → Future<Topic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited