TopicBasicApi class

Constructors

TopicBasicApi(String _sdkId, Object _dartSdk)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addParticipant(String entityId, String dataOwnerId, TopicRole topicRole) → Future<EncryptedTopic>
createTopic(EncryptedTopic entity) → Future<EncryptedTopic>
deleteTopic(Topic topic) → Future<DocIdentifier>
deleteTopicById(String entityId, String rev) → Future<DocIdentifier>
deleteTopics(List<Topic> topics) → Future<List<DocIdentifier>>
deleteTopicsByIds(List<StoredDocumentIdentifier> entityIds) → Future<List<DocIdentifier>>
filterTopicsBy(BaseFilterOptions<Topic> filter) → Future<PaginatedListIterator<EncryptedTopic>>
filterTopicsBySorted(BaseSortableFilterOptions<Topic> filter) → Future<PaginatedListIterator<EncryptedTopic>>
getTopic(String entityId) → Future<EncryptedTopic?>
getTopics(List<String> entityIds) → Future<List<EncryptedTopic>>
matchTopicsBy(BaseFilterOptions<Topic> filter) → Future<List<String>>
matchTopicsBySorted(BaseSortableFilterOptions<Topic> filter) → Future<List<String>>
modifyTopic(EncryptedTopic entity) → Future<EncryptedTopic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeTopic(Topic topic) → Future<void>
purgeTopicById(String id, String rev) → Future<void>
removeParticipant(String entityId, String dataOwnerId) → Future<EncryptedTopic>
subscribeToEvents(Set<SubscriptionEventType> events, BaseFilterOptions<Topic> filter, {EntitySubscriptionConfiguration? subscriptionConfig}) → Future<EntitySubscription<EncryptedTopic>>
toString() → String
A string representation of this object.
inherited
undeleteTopic(Topic topic) → Future<Topic>
undeleteTopicById(String id, String rev) → Future<EncryptedTopic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited