ClassificationShareOptions class abstract

Annotations
  • @freezed

Constructors

ClassificationShareOptions({@Default.new(RequestedPermission.maxWrite) RequestedPermission requestedPermissions, @Default.new(ShareMetadataBehaviour.ifAvailable) ShareMetadataBehaviour shareEncryptionKey, @Default.new(ShareMetadataBehaviour.ifAvailable) ShareMetadataBehaviour sharePatientId, @Default.new(SecretIdShareOptionsAllAvailable()) SecretIdShareOptions shareSecretIds})
const
factory

Properties

copyWith → $ClassificationShareOptionsCopyWith<ClassificationShareOptions>
Create a copy of ClassificationShareOptions with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
requestedPermissions → RequestedPermission
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareEncryptionKey → ShareMetadataBehaviour
no setterinherited
sharePatientId → ShareMetadataBehaviour
no setterinherited
shareSecretIds → SecretIdShareOptions
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(ClassificationShareOptions value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → ClassificationShareOptions