CardinalStateError class

A state error produced by the cardinal sdk with optionally the added native stack trace.

Inheritance

Constructors

CardinalStateError(String message, String? platformStackTrace)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
platformStackTrace → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited