ApplicationSettings class abstract

Implemented types
Annotations
  • @freezed

Constructors

ApplicationSettings({required String id, @Default.new(null) String? rev, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) int? deletionDate, @Default.new({}) Map<String, String> settings})
const
factory

Properties

author → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $ApplicationSettingsCopyWith<ApplicationSettings>
Create a copy of ApplicationSettings with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
deletionDate → int?
no setterinherited
endOfLife → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
medicalLocationId → String?
no setterinherited
modified → int?
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → Map<String, String>
no setterinherited
tags → Set<CodeStub>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(ApplicationSettings value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → ApplicationSettings