CodeIdentification<K> class abstract interface

Implementers

Properties

code → String?
final
context → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → K
no setter
label → Map<String, String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final
version → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited