CodeStub class abstract

Implemented types
Annotations
  • @freezed

Constructors

CodeStub({@Default.new(null) String? id, @Default.new(null) String? context, @Default.new(null) String? type, @Default.new(null) String? code, @Default.new(null) String? version, @Default.new(null) String? contextLabel, @Default.new(null) Map<String, String>? label})
const
factory

Properties

code → String?
no setterinherited
context → String?
no setterinherited
contextLabel → String?
no setterinherited
copyWith → $CodeStubCopyWith<CodeStub>
Create a copy of CodeStub with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
label → Map<String, String>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
no setterinherited
version → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(CodeStub value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → CodeStub