CryptoActor class abstract interface

Implemented types
Implementers

Properties

aesExchangeKeys → Map<AesExchangeKeyEntryKeyString, Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>>
final
cryptoActorProperties → Set<DecryptedPropertyStub>?
final
hashCode → int
The hash code for this object.
no setterinherited
hcPartyKeys → Map<String, List<HexString>>
final
id → String
no setterinherited
parentId → String?
no setter
privateKeyShamirPartitions → Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>
final
publicKey → CardinalRsaPublicKey?
final
publicKeysForOaepWithSha256 → Set<CardinalRsaPublicKey>
final
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferKeys → Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(CryptoActor value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → CryptoActor