ICureDocument<T> class abstract interface

Implemented types
Implementers

Properties

author → String?
final
codes → Set<CodeStub>
finalinherited
created → int?
final
endOfLife → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → T
no setterinherited
medicalLocationId → String?
final
modified → int?
final
responsible → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Set<CodeStub>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited