Identifier class abstract

Annotations
  • @freezed

Constructors

Identifier({@Default.new(null) String? id, @Default.new(null) String? assigner, @Default.new(null) String? start, @Default.new(null) String? end, @Default.new(null) String? system, @Default.new(null) CodeStub? type, @Default.new(null) String? use, @Default.new(null) String? value})
const
factory

Properties

assigner → String?
no setterinherited
copyWith → $IdentifierCopyWith<Identifier>
Create a copy of Identifier with the given fields replaced by the non-null parameter values.
no setterinherited
end → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → String?
no setterinherited
system → String?
no setterinherited
type → CodeStub?
no setterinherited
use → String?
no setterinherited
value → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Identifier value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Identifier