Classification class sealed

Implemented types
Implementers

Properties

author → String?
final
codes → Set<CodeStub>
final
created → int?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
delegations → Map<String, Set<Delegation>>
final
deletionDate → int?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
label → String
final
medicalLocationId → String?
final
modified → int?
final
parentId → String?
final
responsible → String?
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final
tags → Set<CodeStub>
final
templateId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Classification value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Classification
override