Code class abstract

Implemented types
Annotations
  • @freezed

Constructors

Code({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new(null) String? context, @Default.new(null) String? type, @Default.new(null) String? code, @Default.new(null) String? version, @Default.new(null) Map<String, String>? label, @Default.new(null) String? author, @Default.new({}) Set<String> regions, @Default.new({}) Set<Periodicity> periodicity, @Default.new(null) int? level, @Default.new({}) Set<String> links, @Default.new({}) Map<String, List<String>> qualifiedLinks, @Default.new({}) Set<CodeFlag> flags, @Default.new({}) Map<String, Set<String>> searchTerms, @Default.new(null) String? data, @Default.new({}) Map<AppendixType, String> appendices, @Default.new(false) bool disabled})
const
factory

Properties

appendices → Map<AppendixType, String>
no setterinherited
author → String?
no setterinherited
code → String?
no setterinherited
context → String?
no setterinherited
copyWith → $CodeCopyWith<Code>
Create a copy of Code with the given fields replaced by the non-null parameter values.
no setterinherited
data → String?
no setterinherited
deletionDate → int?
no setterinherited
disabled → bool
no setterinherited
flags → Set<CodeFlag>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
label → Map<String, String>?
no setterinherited
level → int?
no setterinherited
no setterinherited
periodicity → Set<Periodicity>
no setterinherited
no setterinherited
regions → Set<String>
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTerms → Map<String, Set<String>>
no setterinherited
type → String?
no setterinherited
version → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Code value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Code