Contact class sealed

Implemented types
Implementers

Properties

author → String?
final
closingDate → int?
final
codes → Set<CodeStub>
final
created → int?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
delegations → Map<String, Set<Delegation>>
final
deletionDate → int?
final
descr → String?
final
encounterLocation → Address?
no setter
encounterType → CodeStub?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
externalId → String?
final
groupId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
healthcarePartyId → String?
final
id → String
final
identifier → List<Identifier>
final
location → String?
final
medicalLocationId → String?
final
modified → int?
final
modifiedContactId → String?
final
notes → List<Annotation>
final
openingDate → int?
final
participants → Map<ParticipantType, String>
final
responsible → String?
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final
services → Set<Service>
no setter
subContacts → Set<SubContact>
no setter
tags → Set<CodeStub>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Contact value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Contact
override