DecryptedContact class abstract

Implemented types
Annotations
  • @freezed

Constructors

DecryptedContact({required String id, @Default.new(null) String? rev, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new([]) List<Identifier> identifier, @Default.new(null) int? endOfLife, @Default.new(null) int? deletionDate, @Default.new(null) String? groupId, @Default.new(null) int? openingDate, @Default.new(null) int? closingDate, @Default.new(null) String? descr, @Default.new(null) String? location, @Default.new(null) String? externalId, @Default.new(null) CodeStub? encounterType, @Default.new(null) DecryptedAddress? encounterLocation, @Default.new({}) Set<DecryptedSubContact> subContacts, @Default.new({}) Set<DecryptedService> services, @Default.new({}) Map<ParticipantType, String> participants, @Default.new(null) String? healthcarePartyId, @Default.new(null) String? modifiedContactId, @Default.new({}) Set<String> secretForeignKeys, @Default.new({}) Map<String, Set<Delegation>> cryptedForeignKeys, @Default.new({}) Map<String, Set<Delegation>> delegations, @Default.new({}) Map<String, Set<Delegation>> encryptionKeys, @Default.new(null) Base64String? encryptedSelf, @Default.new(null) SecurityMetadata? securityMetadata, @Default.new([]) List<Annotation> notes})
const
factory

Properties

author → String?
no setterinherited
closingDate → int?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $DecryptedContactCopyWith<DecryptedContact>
Create a copy of DecryptedContact with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
cryptedForeignKeys → Map<String, Set<Delegation>>
no setterinherited
delegations → Map<String, Set<Delegation>>
no setterinherited
deletionDate → int?
no setterinherited
descr → String?
no setterinherited
encounterLocation → DecryptedAddress?
no setterinherited
encounterType → CodeStub?
no setterinherited
encryptedSelf → String?
no setterinherited
encryptionKeys → Map<String, Set<Delegation>>
no setterinherited
endOfLife → int?
no setterinherited
externalId → String?
no setterinherited
groupId → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
healthcarePartyId → String?
no setterinherited
id → String
no setterinherited
identifier → List<Identifier>
no setterinherited
location → String?
no setterinherited
medicalLocationId → String?
no setterinherited
modified → int?
no setterinherited
modifiedContactId → String?
no setterinherited
notes → List<Annotation>
no setterinherited
openingDate → int?
no setterinherited
participants → Map<ParticipantType, String>
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
no setterinherited
securityMetadata → SecurityMetadata?
no setterinherited
services → Set<DecryptedService>
no setterinherited
subContacts → Set<DecryptedSubContact>
no setterinherited
tags → Set<CodeStub>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DecryptedContact value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → DecryptedContact
override