DatabaseInfo class abstract

Annotations
  • @freezed

Constructors

DatabaseInfo({required String id, @Default.new(null) String? updateSeq, @Default.new(null) int? fileSize, @Default.new(null) int? externalSize, @Default.new(null) int? activeSize, @Default.new(null) int? docs, @Default.new(null) int? q, @Default.new(null) int? n, @Default.new(null) int? w, @Default.new(null) int? r})
const
factory

Properties

activeSize → int?
no setterinherited
copyWith → $DatabaseInfoCopyWith<DatabaseInfo>
Create a copy of DatabaseInfo with the given fields replaced by the non-null parameter values.
no setterinherited
docs → int?
no setterinherited
externalSize → int?
no setterinherited
fileSize → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
n → int?
no setterinherited
q → int?
no setterinherited
r → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateSeq → String?
no setterinherited
w → int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DatabaseInfo value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → DatabaseInfo