DesignDocument class abstract

Annotations
  • @freezed

Constructors

DesignDocument({required String id, @Default.new(null) String? rev, @Default.new({}) Map<String, String> revHistory, @Default.new(null) String? language, @Default.new({}) Map<String, View> views, @Default.new({}) Map<String, String> lists, @Default.new({}) Map<String, String> shows, @Default.new(null) Map<String, String>? updateHandlers, @Default.new({}) Map<String, String> filters})
const
factory

Properties

copyWith → $DesignDocumentCopyWith<DesignDocument>
Create a copy of DesignDocument with the given fields replaced by the non-null parameter values.
no setterinherited
filters → Map<String, String>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
language → String?
no setterinherited
lists → Map<String, String>
no setterinherited
rev → String?
no setterinherited
revHistory → Map<String, String>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shows → Map<String, String>
no setterinherited
updateHandlers → Map<String, String>?
no setterinherited
views → Map<String, View>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DesignDocument value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → DesignDocument