ReplicationStats class abstract

Annotations
  • @freezed

Constructors

ReplicationStats({@Default.new(null) int? revisionsChecked, @Default.new(null) int? missingRevisionsFound, @Default.new(null) int? docsRead, @Default.new(null) int? docsWritten, @Default.new(null) int? changesPending, @Default.new(null) int? docWriteFailures, @Default.new(null) String? checkpointedSourceSeq, @Default.new(null) String? startTime, @Default.new(null) String? error})
const
factory

Properties

changesPending → int?
no setterinherited
checkpointedSourceSeq → String?
no setterinherited
copyWith → $ReplicationStatsCopyWith<ReplicationStats>
Create a copy of ReplicationStats with the given fields replaced by the non-null parameter values.
no setterinherited
docsRead → int?
no setterinherited
docsWritten → int?
no setterinherited
docWriteFailures → int?
no setterinherited
error → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
missingRevisionsFound → int?
no setterinherited
revisionsChecked → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(ReplicationStats value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → ReplicationStats