ReplicatorDocument class abstract

Implemented types
Annotations
  • @freezed

Constructors

ReplicatorDocument({required String id, @Default.new(null) String? rev, @Default.new(null) Remote? source, @Default.new(null) Remote? target, @Default.new(null) String? owner, @Default.new(null) bool? create_target, @Default.new(null) bool? continuous, @Default.new(null) List<String>? doc_ids, @Default.new(null) String? replicationState, @Default.new(null) String? replicationStateTime, @Default.new(null) ReplicationStats? replicationStats, @Default.new(null) int? errorCount, @Default.new(null) List<Map<String, String>>? revsInfo, @Default.new(null) Map<String, String>? revHistory})
const
factory

Properties

continuous → bool?
no setterinherited
copyWith → $ReplicatorDocumentCopyWith<ReplicatorDocument>
Create a copy of ReplicatorDocument with the given fields replaced by the non-null parameter values.
no setterinherited
create_target → bool?
no setterinherited
doc_ids → List<String>?
no setterinherited
errorCount → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
owner → String?
no setterinherited
replicationState → String?
no setterinherited
replicationStateTime → String?
no setterinherited
replicationStats → ReplicationStats?
no setterinherited
rev → String?
no setterinherited
revHistory → Map<String, String>?
no setterinherited
revsInfo → List<Map<String, String>>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Remote?
no setterinherited
target → Remote?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(ReplicatorDocument value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → ReplicatorDocument