View class abstract

Annotations
  • @freezed

Constructors

View({required String map, @Default.new(null) String? reduce})
const
factory

Properties

copyWith → $ViewCopyWith<View>
Create a copy of View with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
map → String
no setterinherited
reduce → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(View value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → View