Device class abstract

Implemented types
Annotations
  • @freezed

Constructors

Device({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new([]) List<Identifier> identifiers, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) String? medicalLocationId, @Default.new(null) String? externalId, @Default.new(null) String? name, @Default.new(null) String? type, @Default.new(null) String? brand, @Default.new(null) String? model, @Default.new(null) String? serialNumber, @Default.new(null) String? parentId, @Default.new(null) Uint8List? picture, @Default.new({}) Set<DecryptedPropertyStub> properties, @Default.new({}) Map<String, List<HexString>> hcPartyKeys, @Default.new({}) Map<AesExchangeKeyEntryKeyString, Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>> aesExchangeKeys, @Default.new({}) Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>> transferKeys, @Default.new({}) Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString> privateKeyShamirPartitions, @Default.new(null) CardinalRsaPublicKey? publicKey, @Default.new({}) Set<CardinalRsaPublicKey> publicKeysForOaepWithSha256, @Default.new(null) Set<DecryptedPropertyStub>? cryptoActorProperties})
const
factory

Properties

aesExchangeKeys → Map<AesExchangeKeyEntryKeyString, Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>>
no setterinherited
author → String?
no setterinherited
brand → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $DeviceCopyWith<Device>
Create a copy of Device with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
cryptoActorProperties → Set<DecryptedPropertyStub>?
no setterinherited
deletionDate → int?
no setterinherited
endOfLife → int?
no setterinherited
externalId → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hcPartyKeys → Map<String, List<HexString>>
no setterinherited
id → String
no setterinherited
identifiers → List<Identifier>
no setterinherited
medicalLocationId → String?
no setterinherited
model → String?
no setterinherited
modified → int?
no setterinherited
name → String?
no setterinherited
parentId → String?
no setterinherited
picture → Uint8List?
no setterinherited
privateKeyShamirPartitions → Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>
no setterinherited
properties → Set<DecryptedPropertyStub>
no setterinherited
publicKey → CardinalRsaPublicKey?
no setterinherited
publicKeysForOaepWithSha256 → Set<CardinalRsaPublicKey>
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String?
no setterinherited
tags → Set<CodeStub>
no setterinherited
transferKeys → Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>
no setterinherited
type → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Device value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Device
override