Document class sealed

Implemented types
Implementers

Properties

attachmentId → String?
final
author → String?
final
codes → Set<CodeStub>
final
created → int?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
decryptedAttachment → Uint8List?
final
delegations → Map<String, Set<Delegation>>
final
deletedAttachments → List<DeletedAttachment>
final
deletionDate → int?
final
documentLocation → DocumentLocation?
final
documentStatus → DocumentStatus?
final
documentType → DocumentType?
final
encryptedAttachment → Uint8List?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
externalUri → String?
final
externalUuid → String?
final
hash → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
mainUti → String?
final
medicalLocationId → String?
final
modified → int?
final
name → String?
final
objectStoreReference → String?
final
openingContactId → String?
final
otherUtis → Set<String>
final
responsible → String?
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryAttachments → Map<String, DataAttachment>
final
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final
size → int?
final
storedICureDocumentId → String?
final
tags → Set<CodeStub>
final
version → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Document value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Document
override