EncryptedDocument class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedDocument({required String id, @Default.new(null) String? rev, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) int? deletionDate, @Default.new(null) DocumentLocation? documentLocation, @Default.new(null) DocumentType? documentType, @Default.new(null) DocumentStatus? documentStatus, @Default.new(null) String? externalUri, @Default.new(null) String? name, @Default.new(null) String? version, @Default.new(null) String? storedICureDocumentId, @Default.new(null) String? externalUuid, @Default.new(null) int? size, @Default.new(null) String? hash, @Default.new(null) String? openingContactId, @Default.new(null) String? attachmentId, @Default.new(null) String? objectStoreReference, @Default.new(null) String? mainUti, @Default.new({}) Set<String> otherUtis, @Default.new({}) Map<String, DataAttachment> secondaryAttachments, @Default.new([]) List<DeletedAttachment> deletedAttachments, @Default.new(null) Uint8List? encryptedAttachment, @Default.new(null) Uint8List? decryptedAttachment, @Default.new({}) Set<String> secretForeignKeys, @Default.new({}) Map<String, Set<Delegation>> cryptedForeignKeys, @Default.new({}) Map<String, Set<Delegation>> delegations, @Default.new({}) Map<String, Set<Delegation>> encryptionKeys, @Default.new(null) Base64String? encryptedSelf, @Default.new(null) SecurityMetadata? securityMetadata})
const
factory

Properties

attachmentId → String?
no setterinherited
author → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $EncryptedDocumentCopyWith<EncryptedDocument>
Create a copy of EncryptedDocument with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
cryptedForeignKeys → Map<String, Set<Delegation>>
no setterinherited
decryptedAttachment → Uint8List?
no setterinherited
delegations → Map<String, Set<Delegation>>
no setterinherited
deletedAttachments → List<DeletedAttachment>
no setterinherited
deletionDate → int?
no setterinherited
documentLocation → DocumentLocation?
no setterinherited
documentStatus → DocumentStatus?
no setterinherited
documentType → DocumentType?
no setterinherited
encryptedAttachment → Uint8List?
no setterinherited
encryptedSelf → String?
no setterinherited
encryptionKeys → Map<String, Set<Delegation>>
no setterinherited
endOfLife → int?
no setterinherited
externalUri → String?
no setterinherited
externalUuid → String?
no setterinherited
hash → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
mainUti → String?
no setterinherited
medicalLocationId → String?
no setterinherited
modified → int?
no setterinherited
name → String?
no setterinherited
objectStoreReference → String?
no setterinherited
openingContactId → String?
no setterinherited
otherUtis → Set<String>
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryAttachments → Map<String, DataAttachment>
no setterinherited
secretForeignKeys → Set<String>
no setterinherited
securityMetadata → SecurityMetadata?
no setterinherited
size → int?
no setterinherited
storedICureDocumentId → String?
no setterinherited
tags → Set<CodeStub>
no setterinherited
version → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedDocument value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedDocument
override