DocumentTemplate class abstract

Implemented types
Annotations
  • @freezed

Constructors

DocumentTemplate({required String id, @Default.new(null) String? rev, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) int? deletionDate, @Default.new(null) Uint8List? attachment, @Default.new(null) DocumentType? documentType, @Default.new(null) String? mainUti, @Default.new(null) String? name, @Default.new({}) Set<String> otherUtis, @Default.new(null) String? attachmentId, @Default.new(null) ReportVersion? version, @Default.new(null) String? owner, @Default.new(null) String? guid, @Default.new(null) DocumentGroup? group, @Default.new(null) String? descr, @Default.new(null) String? disabled, @Default.new(null) CodeStub? specialty})
const
factory

Properties

attachment → Uint8List?
no setterinherited
attachmentId → String?
no setterinherited
author → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $DocumentTemplateCopyWith<DocumentTemplate>
Create a copy of DocumentTemplate with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
deletionDate → int?
no setterinherited
descr → String?
no setterinherited
disabled → String?
no setterinherited
documentType → DocumentType?
no setterinherited
endOfLife → int?
no setterinherited
group → DocumentGroup?
no setterinherited
guid → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
mainUti → String?
no setterinherited
medicalLocationId → String?
no setterinherited
modified → int?
no setterinherited
name → String?
no setterinherited
otherUtis → Set<String>
no setterinherited
owner → String?
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specialty → CodeStub?
no setterinherited
tags → Set<CodeStub>
no setterinherited
version → ReportVersion?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DocumentTemplate value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → DocumentTemplate