Address class sealed

Implemented types
Implementers

Properties

addressType → AddressType?
final
city → String?
final
codes → Set<CodeStub>
final
country → String?
final
descr → String?
final
encryptedSelf → String?
final
hashCode → int
The hash code for this object.
no setterinherited
houseNumber → String?
final
identifier → List<Identifier>
final
note → String?
final
notes → List<Annotation>
final
postalCode → String?
final
postboxNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
final
street → String?
final
tags → Set<CodeStub>
final
telecoms → List<Telecom>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Address value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Address