EncryptedAddress class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedAddress({@Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new([]) List<Identifier> identifier, @Default.new(null) AddressType? addressType, @Default.new(null) String? descr, @Default.new(null) String? street, @Default.new(null) String? houseNumber, @Default.new(null) String? postboxNumber, @Default.new(null) String? postalCode, @Default.new(null) String? city, @Default.new(null) String? state, @Default.new(null) String? country, @Default.new(null) String? note, @Default.new([]) List<Annotation> notes, @Default.new([]) List<EncryptedTelecom> telecoms, @Default.new(null) Base64String? encryptedSelf})
const
factory

Properties

addressType → AddressType?
no setterinherited
city → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $EncryptedAddressCopyWith<EncryptedAddress>
Create a copy of EncryptedAddress with the given fields replaced by the non-null parameter values.
no setterinherited
country → String?
no setterinherited
descr → String?
no setterinherited
encryptedSelf → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
houseNumber → String?
no setterinherited
identifier → List<Identifier>
no setterinherited
note → String?
no setterinherited
notes → List<Annotation>
no setterinherited
postalCode → String?
no setterinherited
postboxNumber → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
no setterinherited
street → String?
no setterinherited
tags → Set<CodeStub>
no setterinherited
telecoms → List<EncryptedTelecom>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedAddress value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedAddress
override