Annotation class abstract

Implemented types
Annotations
  • @freezed

Constructors

Annotation({required String id, @Default.new(null) String? author, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? text, @Default.new({}) Map<String, String> markdown, @Default.new(null) String? location, @Default.new(null) bool? confidential, @Default.new({}) Set<CodeStub> tags, @Default.new(null) String? encryptedSelf})
const
factory

Properties

author → String?
no setterinherited
confidential → bool?
no setterinherited
copyWith → $AnnotationCopyWith<Annotation>
Create a copy of Annotation with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
encryptedSelf → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
location → String?
no setterinherited
markdown → Map<String, String>
no setterinherited
modified → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Set<CodeStub>
no setterinherited
text → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Annotation value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Annotation