Content class sealed

Implementers

Properties

binaryValue → Uint8List?
final
booleanValue → bool?
final
compoundValue → List<Service>?
no setter
documentId → String?
final
fuzzyDateValue → int?
final
hashCode → int
The hash code for this object.
no setterinherited
instantValue → DateTime?
final
measureValue → Measure?
final
medicationValue → Medication?
final
numberValue → double?
final
range → List<Measure>?
final
ratio → List<Measure>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
final
timeSeries → TimeSeries?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Content value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Content