EncryptedContent class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedContent({@Default.new(null) String? stringValue, @Default.new(null) double? numberValue, @Default.new(null) bool? booleanValue, @Default.new(null) DateTime? instantValue, @Default.new(null) int? fuzzyDateValue, @Default.new(null) Uint8List? binaryValue, @Default.new(null) String? documentId, @Default.new(null) Measure? measureValue, @Default.new(null) Medication? medicationValue, @Default.new(null) TimeSeries? timeSeries, @Default.new(null) List<EncryptedService>? compoundValue, @Default.new(null) List<Measure>? ratio, @Default.new(null) List<Measure>? range})
const
factory

Properties

binaryValue → Uint8List?
no setterinherited
booleanValue → bool?
no setterinherited
compoundValue → List<EncryptedService>?
no setterinherited
copyWith → $EncryptedContentCopyWith<EncryptedContent>
Create a copy of EncryptedContent with the given fields replaced by the non-null parameter values.
no setterinherited
documentId → String?
no setterinherited
fuzzyDateValue → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
instantValue → DateTime?
no setterinherited
measureValue → Measure?
no setterinherited
medicationValue → Medication?
no setterinherited
numberValue → double?
no setterinherited
range → List<Measure>?
no setterinherited
ratio → List<Measure>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
no setterinherited
timeSeries → TimeSeries?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedContent value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedContent
override