DatabaseSynchronization class abstract

Annotations
  • @freezed

Constructors

DatabaseSynchronization({@Default.new(null) String? source, @Default.new(null) String? target, @Default.new(null) String? filter, @Default.new(null) DatabaseSynchronizationTarget? localTarget})
const
factory

Properties

copyWith → $DatabaseSynchronizationCopyWith<DatabaseSynchronization>
Create a copy of DatabaseSynchronization with the given fields replaced by the non-null parameter values.
no setterinherited
filter → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
localTarget → DatabaseSynchronizationTarget?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
no setterinherited
target → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DatabaseSynchronization value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → DatabaseSynchronization