Duration class abstract

Annotations
  • @freezed

Constructors

Duration({@Default.new(null) double? value, @Default.new(null) CodeStub? unit})
const
factory

Properties

copyWith → $DurationCopyWith<Duration>
Create a copy of Duration with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → CodeStub?
no setterinherited
value → double?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Duration value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Duration