EncryptedEpisode class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedEpisode({required String id, @Default.new(null) String? name, @Default.new(null) String? comment, @Default.new(null) int? startDate, @Default.new(null) int? endDate, @Default.new(null) Base64String? encryptedSelf})
const
factory

Properties

comment → String?
no setterinherited
copyWith → $EncryptedEpisodeCopyWith<EncryptedEpisode>
Create a copy of EncryptedEpisode with the given fields replaced by the non-null parameter values.
no setterinherited
encryptedSelf → String?
no setterinherited
endDate → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
name → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedEpisode value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedEpisode
override