Field class abstract interface

Implemented types
Implementers

Properties

codifications → List<String>?
final
columns → int?
final
field → String
final
grows → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
hideCondition → String?
final
labels → Map<String, String>?
final
multiline → bool?
final
now → bool?
final
options → Map<String, String>?
final
required → bool?
final
rows → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
final
shortLabel → String?
final
tags → List<String>?
final
translate → bool?
final
unit → String?
final
value → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Field value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Field
override