MultipleChoice class abstract

Implemented types
Annotations
  • @freezed

Constructors

MultipleChoice({required String field, @Default.new(null) String? shortLabel, @Default.new(null) int? rows, @Default.new(null) int? columns, @Default.new(null) bool? grows, @Default.new(null) bool? multiline, @Default.new(null) String? schema, @Default.new(null) List<String>? tags, @Default.new(null) List<String>? codifications, @Default.new(null) Map<String, String>? options, @Default.new(null) Map<String, String>? labels, @Default.new(null) String? value, @Default.new(null) String? unit, @Default.new(null) bool? required, @Default.new(null) String? hideCondition, @Default.new(null) bool? now, @Default.new(null) bool? translate})
const
factory

Properties

codifications → List<String>?
no setterinherited
columns → int?
no setterinherited
copyWith → $MultipleChoiceCopyWith<MultipleChoice>
Create a copy of MultipleChoice with the given fields replaced by the non-null parameter values.
no setterinherited
field → String
no setterinherited
grows → bool?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hideCondition → String?
no setterinherited
labels → Map<String, String>?
no setterinherited
multiline → bool?
no setterinherited
now → bool?
no setterinherited
options → Map<String, String>?
no setterinherited
required → bool?
no setterinherited
rows → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
no setterinherited
shortLabel → String?
no setterinherited
tags → List<String>?
no setterinherited
translate → bool?
no setterinherited
unit → String?
no setterinherited
value → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(MultipleChoice value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → MultipleChoice
override