Section class abstract

Annotations
  • @freezed

Constructors

Section({required String section, required List<StructureElement> fields, @Default.new(null) String? description, @Default.new(null) List<String>? keywords})
const
factory

Properties

copyWith → $SectionCopyWith<Section>
Create a copy of Section with the given fields replaced by the non-null parameter values.
no setterinherited
description → String?
no setterinherited
fields → List<StructureElement>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
keywords → List<String>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Section value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Section