IdentityDocumentReader class abstract

Annotations
  • @freezed

Constructors

IdentityDocumentReader({@Default.new(null) String? justificatifDocumentNumber, @Default.new(null) String? supportSerialNumber, @Default.new(null) int? timeReadingEIdDocument, @Default.new(0) int eidDocumentSupportType, @Default.new(0) int reasonManualEncoding, @Default.new(0) int reasonUsingVignette})
const
factory

Properties

copyWith → $IdentityDocumentReaderCopyWith<IdentityDocumentReader>
Create a copy of IdentityDocumentReader with the given fields replaced by the non-null parameter values.
no setterinherited
eidDocumentSupportType → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
justificatifDocumentNumber → String?
no setterinherited
reasonManualEncoding → int
no setterinherited
reasonUsingVignette → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportSerialNumber → String?
no setterinherited
timeReadingEIdDocument → int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(IdentityDocumentReader value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → IdentityDocumentReader