EncryptedInsurability class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedInsurability({@Default.new({}) Map<String, String> parameters, @Default.new(null) bool? hospitalisation, @Default.new(null) bool? ambulatory, @Default.new(null) bool? dental, @Default.new(null) String? identificationNumber, @Default.new(null) String? insuranceId, @Default.new(null) int? startDate, @Default.new(null) int? endDate, @Default.new(null) String? titularyId, @Default.new(null) Base64String? encryptedSelf})
const
factory

Properties

ambulatory → bool?
no setterinherited
copyWith → $EncryptedInsurabilityCopyWith<EncryptedInsurability>
Create a copy of EncryptedInsurability with the given fields replaced by the non-null parameter values.
no setterinherited
dental → bool?
no setterinherited
encryptedSelf → Base64String?
no setterinherited
endDate → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hospitalisation → bool?
no setterinherited
identificationNumber → Base64String?
no setterinherited
insuranceId → Base64String?
no setterinherited
parameters → Map<String, String>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → int?
no setterinherited
titularyId → Base64String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedInsurability value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedInsurability
override