Insurability class sealed

Implemented types
Implementers

Properties

ambulatory → bool?
final
dental → bool?
final
encryptedSelf → Base64String?
final
endDate → int?
final
hashCode → int
The hash code for this object.
no setterinherited
hospitalisation → bool?
final
identificationNumber → Base64String?
final
insuranceId → Base64String?
final
parameters → Map<String, String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → int?
final
titularyId → Base64String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Insurability value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Insurability