DecryptedInvoicingCode class abstract

Implemented types
Annotations
  • @freezed

Constructors

DecryptedInvoicingCode({required String? id, @Default.new(null) int? dateCode, @Default.new(null) String? logicalId, @Default.new(null) String? label, @Default.new(null) String? userId, @Default.new(null) String? contactId, @Default.new(null) String? serviceId, @Default.new(null) String? tarificationId, @Default.new(null) String? code, @Default.new(null) PaymentType? paymentType, @Default.new(null) double? paid, @Default.new(null) double? totalAmount, @Default.new(null) double? reimbursement, @Default.new(null) double? patientIntervention, @Default.new(null) double? doctorSupplement, @Default.new(null) double? conventionAmount, @Default.new(null) double? vat, @Default.new(null) String? error, @Default.new(null) String? contract, @Default.new(null) int? contractDate, @Default.new(null) int? units, @Default.new(null) int? side, @Default.new(null) int? timeOfDay, @Default.new(null) int? eidReadingHour, @Default.new(null) String? eidReadingValue, @Default.new(null) int? override3rdPayerCode, @Default.new(null) String? override3rdPayerReason, @Default.new(null) int? transplantationCode, @Default.new(null) int? prescriberNorm, @Default.new(null) String? productLabel, @Default.new(null) int? percentNorm, @Default.new(null) String? prescriberNihii, @Default.new(null) String? relatedCode, @Default.new(null) int? prescriptionDate, @Default.new(null) int? derogationMaxNumber, @Default.new(null) String? prescriberSsin, @Default.new(null) String? prescriberLastName, @Default.new(null) String? prescriberFirstName, @Default.new(null) String? prescriberCdHcParty, @Default.new(null) String? locationNihii, @Default.new(null) String? locationCdHcParty, @Default.new(null) int? locationService, @Default.new(null) int? admissionDate, @Default.new(null) bool? canceled, @Default.new(null) bool? accepted, @Default.new(null) bool? pending, @Default.new(null) bool? resent, @Default.new(null) bool? archived, @Default.new(null) bool? lost, @Default.new(null) int? insuranceJustification, @Default.new(null) int? cancelPatientInterventionReason, @Default.new(null) int? status, @Default.new(null) Base64String? encryptedSelf})
const
factory

Properties

accepted → bool?
no setterinherited
admissionDate → int?
no setterinherited
archived → bool?
no setterinherited
canceled → bool?
no setterinherited
cancelPatientInterventionReason → int?
no setterinherited
code → String?
no setterinherited
contactId → String?
no setterinherited
contract → String?
no setterinherited
contractDate → int?
no setterinherited
conventionAmount → double?
no setterinherited
copyWith → $DecryptedInvoicingCodeCopyWith<DecryptedInvoicingCode>
Create a copy of DecryptedInvoicingCode with the given fields replaced by the non-null parameter values.
no setterinherited
dateCode → int?
no setterinherited
derogationMaxNumber → int?
no setterinherited
doctorSupplement → double?
no setterinherited
eidReadingHour → int?
no setterinherited
eidReadingValue → String?
no setterinherited
encryptedSelf → String?
no setterinherited
error → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
insuranceJustification → int?
no setterinherited
label → String?
no setterinherited
locationCdHcParty → String?
no setterinherited
locationNihii → String?
no setterinherited
locationService → int?
no setterinherited
logicalId → String?
no setterinherited
lost → bool?
no setterinherited
override3rdPayerCode → int?
no setterinherited
override3rdPayerReason → String?
no setterinherited
no setterinherited
patientIntervention → double?
no setterinherited
paymentType → PaymentType?
no setterinherited
pending → bool?
no setterinherited
percentNorm → int?
no setterinherited
prescriberCdHcParty → String?
no setterinherited
prescriberFirstName → String?
no setterinherited
prescriberLastName → String?
no setterinherited
prescriberNihii → String?
no setterinherited
prescriberNorm → int?
no setterinherited
prescriberSsin → String?
no setterinherited
prescriptionDate → int?
no setterinherited
productLabel → String?
no setterinherited
reimbursement → double?
no setterinherited
relatedCode → String?
no setterinherited
resent → bool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceId → String?
no setterinherited
side → int?
no setterinherited
status → int?
no setterinherited
tarificationId → String?
no setterinherited
timeOfDay → int?
no setterinherited
totalAmount → double?
no setterinherited
transplantationCode → int?
no setterinherited
units → int?
no setterinherited
userId → String?
no setterinherited
vat → double?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DecryptedInvoicingCode value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → DecryptedInvoicingCode
override