InvoicingCode class sealed

Implemented types
Implementers

Properties

accepted → bool?
final
admissionDate → int?
final
archived → bool?
final
canceled → bool?
final
cancelPatientInterventionReason → int?
final
code → String?
final
contactId → String?
final
contract → String?
final
contractDate → int?
final
conventionAmount → double?
final
dateCode → int?
final
derogationMaxNumber → int?
final
doctorSupplement → double?
final
eidReadingHour → int?
final
eidReadingValue → String?
final
encryptedSelf → String?
final
error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
insuranceJustification → int?
final
label → String?
final
locationCdHcParty → String?
final
locationNihii → String?
final
locationService → int?
final
logicalId → String?
final
lost → bool?
final
override3rdPayerCode → int?
final
override3rdPayerReason → String?
final
final
patientIntervention → double?
final
paymentType → PaymentType?
final
pending → bool?
final
percentNorm → int?
final
prescriberCdHcParty → String?
final
prescriberFirstName → String?
final
prescriberLastName → String?
final
prescriberNihii → String?
final
prescriberNorm → int?
final
prescriberSsin → String?
final
prescriptionDate → int?
final
productLabel → String?
final
reimbursement → double?
final
relatedCode → String?
final
resent → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceId → String?
final
side → int?
final
status → int?
final
tarificationId → String?
final
timeOfDay → int?
final
totalAmount → double?
final
transplantationCode → int?
final
units → int?
final
userId → String?
final
vat → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(InvoicingCode value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → InvoicingCode