LetterValue class abstract

Annotations
  • @freezed

Constructors

LetterValue({@Default.new(null) String? letter, @Default.new(null) String? index, @Default.new(null) double? coefficient, @Default.new(null) double? value})
const
factory

Properties

coefficient → double?
no setterinherited
copyWith → $LetterValueCopyWith<LetterValue>
Create a copy of LetterValue with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
index → String?
no setterinherited
letter → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(LetterValue value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → LetterValue