Measure class abstract

Annotations
  • @freezed

Constructors

Measure({@Default.new(null) double? value, @Default.new(null) double? ref, @Default.new(null) int? severity, @Default.new(null) String? severityCode, @Default.new(null) int? evolution, @Default.new(null) String? unit, @Default.new(null) Set<CodeStub>? unitCodes, @Default.new(null) String? comment, @Default.new(null) String? comparator, @Default.new(null) String? sign, @Default.new([]) List<ReferenceRange> referenceRanges})
const
factory

Properties

comment → String?
no setterinherited
comparator → String?
no setterinherited
copyWith → $MeasureCopyWith<Measure>
Create a copy of Measure with the given fields replaced by the non-null parameter values.
no setterinherited
evolution → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
ref → double?
no setterinherited
referenceRanges → List<ReferenceRange>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → int?
no setterinherited
severityCode → String?
no setterinherited
sign → String?
no setterinherited
unit → String?
no setterinherited
unitCodes → Set<CodeStub>?
no setterinherited
value → double?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Measure value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Measure