Partnership class abstract

Annotations
  • @freezed

Constructors

Partnership({@Default.new(null) PartnershipType? type, @Default.new(null) PartnershipStatus? status, @Default.new(null) String? partnerId, @Default.new(null) String? meToOtherRelationshipDescription, @Default.new(null) String? otherToMeRelationshipDescription})
const
factory

Properties

copyWith → $PartnershipCopyWith<Partnership>
Create a copy of Partnership with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
meToOtherRelationshipDescription → String?
no setterinherited
otherToMeRelationshipDescription → String?
no setterinherited
partnerId → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → PartnershipStatus?
no setterinherited
type → PartnershipType?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Partnership value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Partnership