Range class abstract

Annotations
  • @freezed

Constructors

Range({@Default.new(null) double? low, @Default.new(null) double? high})
const
factory

Properties

copyWith → $RangeCopyWith<Range>
Create a copy of Range with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
high → double?
no setterinherited
low → double?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Range value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Range