ReferenceRange class abstract

Annotations
  • @freezed

Constructors

ReferenceRange({@Default.new(null) double? low, @Default.new(null) double? high, @Default.new(null) String? stringValue, @Default.new([]) List<CodeStub> tags, @Default.new([]) List<CodeStub> codes, @Default.new([]) List<Annotation> notes, @Default.new(null) Range? age})
const
factory

Properties

age → Range?
no setterinherited
codes → List<CodeStub>
no setterinherited
copyWith → $ReferenceRangeCopyWith<ReferenceRange>
Create a copy of ReferenceRange with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
high → double?
no setterinherited
low → double?
no setterinherited
notes → List<Annotation>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
no setterinherited
tags → List<CodeStub>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(ReferenceRange value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → ReferenceRange