RoleConfiguration class abstract

Annotations
  • @freezed

Constructors

RoleConfiguration({required RoleConfigurationSource source, @Default.new({}) Set<String> roles})
const
factory

Properties

copyWith → $RoleConfigurationCopyWith<RoleConfiguration>
Create a copy of RoleConfiguration with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
roles → Set<String>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → RoleConfigurationSource
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(RoleConfiguration value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → RoleConfiguration