EncryptedService class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedService({required String id, @Default.new(null) String? transactionId, @Default.new([]) List<Identifier> identifier, @Default.new(null) String? contactId, @Default.new(null) Set<String>? subContactIds, @Default.new(null) Set<String>? plansOfActionIds, @Default.new(null) Set<String>? healthElementsIds, @Default.new(null) Set<String>? formIds, @Default.new({}) Set<String>? secretForeignKeys, @Default.new({}) Map<String, Set<Delegation>> cryptedForeignKeys, @Default.new({}) Map<String, Set<Delegation>> delegations, @Default.new({}) Map<String, Set<Delegation>> encryptionKeys, @Default.new(null) String? label, @Default.new(null) int? index, @Default.new({}) Map<String, EncryptedContent> content, @Default.new(null) String? encryptedContent, @Default.new({}) Map<String, String> textIndexes, @Default.new(null) int? valueDate, @Default.new(null) int? openingDate, @Default.new(null) int? closingDate, @Default.new(null) String? formId, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) int? endOfLife, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new(null) String? comment, @Default.new(null) int? status, @Default.new({}) Set<String> invoicingCodes, @Default.new([]) List<Annotation> notes, @Default.new({}) Map<LinkQualification, Map<String, String>> qualifiedLinks, @Default.new({}) Set<CodeStub> codes, @Default.new({}) Set<CodeStub> tags, @Default.new(null) Base64String? encryptedSelf, @Default.new(null) SecurityMetadata? securityMetadata})
const
factory

Properties

author → String?
no setterinherited
closingDate → int?
no setterinherited
codes → Set<CodeStub>
no setterinherited
comment → String?
no setterinherited
contactId → String?
no setterinherited
content → Map<String, EncryptedContent>
no setterinherited
copyWith → $EncryptedServiceCopyWith<EncryptedService>
Create a copy of EncryptedService with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
cryptedForeignKeys → Map<String, Set<Delegation>>
no setterinherited
delegations → Map<String, Set<Delegation>>
no setterinherited
encryptedContent → String?
no setterinherited
encryptedSelf → String?
no setterinherited
encryptionKeys → Map<String, Set<Delegation>>
no setterinherited
endOfLife → int?
no setterinherited
formId → String?
no setterinherited
formIds → Set<String>?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
healthElementsIds → Set<String>?
no setterinherited
id → String
no setterinherited
identifier → List<Identifier>
no setterinherited
index → int?
no setterinherited
invoicingCodes → Set<String>
no setterinherited
label → String?
no setterinherited
medicalLocationId → String?
no setterinherited
modified → int?
no setterinherited
notes → List<Annotation>
no setterinherited
openingDate → int?
no setterinherited
plansOfActionIds → Set<String>?
no setterinherited
no setterinherited
responsible → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>?
no setterinherited
securityMetadata → SecurityMetadata?
no setterinherited
status → int?
no setterinherited
subContactIds → Set<String>?
no setterinherited
tags → Set<CodeStub>
no setterinherited
textIndexes → Map<String, String>
no setterinherited
transactionId → String?
no setterinherited
valueDate → int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedService value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedService
override