Service class sealed

Implemented types
Implementers

Properties

author → String?
final
closingDate → int?
final
codes → Set<CodeStub>
final
comment → String?
final
contactId → String?
final
content → Map<String, Content>
no setter
created → int?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
delegations → Map<String, Set<Delegation>>
final
encryptedContent → String?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
formId → String?
final
formIds → Set<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
healthElementsIds → Set<String>?
final
id → String
final
identifier → List<Identifier>
final
index → int?
final
invoicingCodes → Set<String>
final
label → String?
final
medicalLocationId → String?
final
modified → int?
final
notes → List<Annotation>
final
openingDate → int?
final
plansOfActionIds → Set<String>?
final
final
responsible → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>?
final
securityMetadata → SecurityMetadata?
final
status → int?
final
subContactIds → Set<String>?
final
tags → Set<CodeStub>
final
textIndexes → Map<String, String>
final
transactionId → String?
final
valueDate → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Service value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Service