EncryptedSubContact class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedSubContact({@Default.new(null) String? id, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) String? descr, @Default.new(null) String? protocol, @Default.new(null) int? status, @Default.new(null) String? formId, @Default.new(null) String? planOfActionId, @Default.new(null) String? healthElementId, @Default.new(null) String? classificationId, @Default.new([]) List<ServiceLink> services, @Default.new(null) Base64String? encryptedSelf})
const
factory

Properties

author → String?
no setterinherited
classificationId → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $EncryptedSubContactCopyWith<EncryptedSubContact>
Create a copy of EncryptedSubContact with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
descr → String?
no setterinherited
encryptedSelf → String?
no setterinherited
endOfLife → int?
no setterinherited
formId → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
healthElementId → String?
no setterinherited
id → String?
no setterinherited
medicalLocationId → String?
no setterinherited
modified → int?
no setterinherited
planOfActionId → String?
no setterinherited
protocol → String?
no setterinherited
responsible → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services → List<ServiceLink>
no setterinherited
status → int?
no setterinherited
tags → Set<CodeStub>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedSubContact value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedSubContact
override