Telecom class sealed

Implemented types
Implementers

Properties

encryptedSelf → Base64String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
telecomDescription → Base64String?
final
telecomNumber → Base64String?
final
telecomType → TelecomType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Telecom value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Telecom