TimeTableItem class abstract

Annotations
  • @freezed

Constructors

TimeTableItem({@Default.new(null) int? rruleStartDate, @Default.new(null) String? rrule, @Default.new(null) int? notBeforeInMinutes, @Default.new(null) int? notAfterInMinutes, @Default.new(null) String? zoneId, @Default.new([]) List<String> days, @Default.new([]) List<String> recurrenceTypes, @Default.new([]) List<TimeTableHour> hours, @Default.new(null) String? calendarItemTypeId, @Default.new(false) bool homeVisit, @Default.new(null) String? placeId, @Default.new(false) bool publicTimeTableItem, @Default.new(true) bool acceptsNewPatient, @Default.new(false) bool unavailable, @Default.new({}) Set<String> reservingRights})
const
factory

Properties

acceptsNewPatient → bool
no setterinherited
calendarItemTypeId → String?
no setterinherited
copyWith → $TimeTableItemCopyWith<TimeTableItem>
Create a copy of TimeTableItem with the given fields replaced by the non-null parameter values.
no setterinherited
days → List<String>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
homeVisit → bool
no setterinherited
hours → List<TimeTableHour>
no setterinherited
notAfterInMinutes → int?
no setterinherited
notBeforeInMinutes → int?
no setterinherited
placeId → String?
no setterinherited
publicTimeTableItem → bool
no setterinherited
recurrenceTypes → List<String>
no setterinherited
reservingRights → Set<String>
no setterinherited
rrule → String?
no setterinherited
rruleStartDate → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unavailable → bool
no setterinherited
zoneId → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(TimeTableItem value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → TimeTableItem