EntityTemplate class abstract

Implemented types
Annotations
  • @freezed

Constructors

EntityTemplate({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new(null) String? userId, @Default.new(null) String? descr, @Default.new(null) Set<String>? keywords, @Default.new(null) String? entityType, @Default.new(null) String? subType, @Default.new(null) bool? defaultTemplate, @Default.new([]) List<Map<String, dynamic>> entity})
const
factory

Properties

copyWith → $EntityTemplateCopyWith<EntityTemplate>
Create a copy of EntityTemplate with the given fields replaced by the non-null parameter values.
no setterinherited
defaultTemplate → bool?
no setterinherited
deletionDate → int?
no setterinherited
descr → String?
no setterinherited
entity → List<Map<String, dynamic>>
no setterinherited
entityType → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
keywords → Set<String>?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subType → String?
no setterinherited
userId → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EntityTemplate value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → EntityTemplate