Form class sealed

Implemented types
Implementers

Properties

anchorId → String?
final
author → String?
final
codes → Set<CodeStub>
final
contactId → String?
final
created → int?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
delegations → Map<String, Set<Delegation>>
final
deletionDate → int?
final
descr → String?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
formTemplateId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
healthElementId → String?
final
id → String
final
logicalUuid → String?
final
medicalLocationId → String?
final
modified → int?
final
openingDate → int?
final
parent → String?
final
planOfActionId → String?
final
responsible → String?
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final
status → String?
final
tags → Set<CodeStub>
final
uniqueId → String?
final
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Form value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Form
override