FormTemplate class abstract

Implemented types
Annotations
  • @freezed

Constructors

FormTemplate({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new(null) FormTemplateLayout? templateLayout, @Default.new(null) Uint8List? rawTemplateLayout, @Default.new(null) String? name, @Default.new(null) String? guid, @Default.new(null) DocumentGroup? group, @Default.new(null) String? descr, @Default.new(null) String? disabled, @Default.new(null) CodeStub? specialty, @Default.new(null) String? author, @Default.new(null) String? formInstancePreferredLocation, @Default.new(null) String? keyboardShortcut, @Default.new(null) String? shortReport, @Default.new(null) String? mediumReport, @Default.new(null) String? longReport, @Default.new({}) Set<String> reports, @Default.new({}) Set<CodeStub> tags, @Default.new(null) String? layoutAttachmentId, @Default.new(null) String? templateLayoutAttachmentId})
const
factory

Properties

author → String?
no setterinherited
copyWith → $FormTemplateCopyWith<FormTemplate>
Create a copy of FormTemplate with the given fields replaced by the non-null parameter values.
no setterinherited
deletionDate → int?
no setterinherited
descr → String?
no setterinherited
disabled → String?
no setterinherited
formInstancePreferredLocation → String?
no setterinherited
group → DocumentGroup?
no setterinherited
guid → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
keyboardShortcut → String?
no setterinherited
layoutAttachmentId → String?
no setterinherited
longReport → String?
no setterinherited
mediumReport → String?
no setterinherited
name → String?
no setterinherited
rawTemplateLayout → Uint8List?
no setterinherited
reports → Set<String>
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortReport → String?
no setterinherited
specialty → CodeStub?
no setterinherited
tags → Set<CodeStub>
no setterinherited
templateLayout → FormTemplateLayout?
no setterinherited
templateLayoutAttachmentId → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(FormTemplate value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → FormTemplate