FrontEndMigration class abstract

Implemented types
Annotations
  • @freezed

Constructors

FrontEndMigration({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new(null) String? name, @Default.new(null) int? startDate, @Default.new(null) int? endDate, @Default.new(null) FrontEndMigrationStatus? status, @Default.new(null) String? logs, @Default.new(null) String? userId, @Default.new(null) String? startKey, @Default.new(null) String? startKeyDocId, @Default.new(null) int? processCount, @Default.new({}) Set<DecryptedPropertyStub> properties})
const
factory

Properties

copyWith → $FrontEndMigrationCopyWith<FrontEndMigration>
Create a copy of FrontEndMigration with the given fields replaced by the non-null parameter values.
no setterinherited
deletionDate → int?
no setterinherited
endDate → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
logs → String?
no setterinherited
name → String?
no setterinherited
processCount → int?
no setterinherited
properties → Set<DecryptedPropertyStub>
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → int?
no setterinherited
startKey → String?
no setterinherited
startKeyDocId → String?
no setterinherited
status → FrontEndMigrationStatus?
no setterinherited
userId → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(FrontEndMigration value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → FrontEndMigration