Group class abstract

Implemented types
Annotations
  • @freezed

Constructors

Group({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new({}) Set<CodeStub> tags, @Default.new(null) String? name, @Default.new(null) String? password, @Default.new(null) List<String>? servers, @Default.new(false) bool superAdmin, @Default.new({}) Set<DecryptedPropertyStub> properties, @Default.new({}) Map<UserType, Set<String>> defaultUserRoles, @Default.new({}) Map<String, OperationToken> operationTokens, @Default.new({}) Map<String, String> sharedEntities, @Default.new(null) String? minimumKrakenVersion, @Default.new({}) Map<String, ExternalJwtConfig> externalJwtConfig, required AuthenticationClass minimumAuthenticationClassForElevatedPrivileges, @Default.new(null) String? superGroup, @Default.new(null) String? applicationId})
const
factory

Properties

applicationId → String?
no setterinherited
copyWith → $GroupCopyWith<Group>
Create a copy of Group with the given fields replaced by the non-null parameter values.
no setterinherited
defaultUserRoles → Map<UserType, Set<String>>
no setterinherited
deletionDate → int?
no setterinherited
externalJwtConfig → Map<String, ExternalJwtConfig>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
minimumAuthenticationClassForElevatedPrivileges → AuthenticationClass
no setterinherited
minimumKrakenVersion → String?
no setterinherited
name → String?
no setterinherited
operationTokens → Map<String, OperationToken>
no setterinherited
password → String?
no setterinherited
properties → Set<DecryptedPropertyStub>
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servers → List<String>?
no setterinherited
sharedEntities → Map<String, String>
no setterinherited
superAdmin → bool
no setterinherited
superGroup → String?
no setterinherited
tags → Set<CodeStub>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Group value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Group