DecryptedHealthElement class abstract

Implemented types
Annotations
  • @freezed

Constructors

DecryptedHealthElement({required String id, @Default.new([]) List<Identifier> identifiers, @Default.new(null) String? rev, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) int? deletionDate, @Default.new(null) String? healthElementId, @Default.new(null) int? valueDate, @Default.new(null) int? openingDate, @Default.new(null) int? closingDate, @Default.new(null) String? descr, @Default.new(null) String? note, @Default.new([]) List<Annotation> notes, @Default.new(true) bool relevant, @Default.new(null) String? idOpeningContact, @Default.new(null) String? idClosingContact, @Default.new(null) String? idService, @Default.new(0) int status, @Default.new(null) Laterality? laterality, @Default.new([]) List<DecryptedPlanOfAction> plansOfAction, @Default.new([]) List<DecryptedEpisode> episodes, @Default.new([]) List<DecryptedCareTeamMember> careTeam, @Default.new({}) Set<String> secretForeignKeys, @Default.new({}) Map<String, Set<Delegation>> cryptedForeignKeys, @Default.new({}) Map<String, Set<Delegation>> delegations, @Default.new({}) Map<String, Set<Delegation>> encryptionKeys, @Default.new(null) Base64String? encryptedSelf, @Default.new(null) SecurityMetadata? securityMetadata})
const
factory

Properties

author → String?
no setterinherited
careTeam → List<DecryptedCareTeamMember>
no setterinherited
closingDate → int?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $DecryptedHealthElementCopyWith<DecryptedHealthElement>
Create a copy of DecryptedHealthElement with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
cryptedForeignKeys → Map<String, Set<Delegation>>
no setterinherited
delegations → Map<String, Set<Delegation>>
no setterinherited
deletionDate → int?
no setterinherited
descr → String?
no setterinherited
encryptedSelf → String?
no setterinherited
encryptionKeys → Map<String, Set<Delegation>>
no setterinherited
endOfLife → int?
no setterinherited
episodes → List<DecryptedEpisode>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
healthElementId → String?
no setterinherited
id → String
no setterinherited
idClosingContact → String?
no setterinherited
identifiers → List<Identifier>
no setterinherited
idOpeningContact → String?
no setterinherited
idService → String?
no setterinherited
laterality → Laterality?
no setterinherited
medicalLocationId → String?
no setterinherited
modified → int?
no setterinherited
note → String?
no setterinherited
notes → List<Annotation>
no setterinherited
openingDate → int?
no setterinherited
plansOfAction → List<DecryptedPlanOfAction>
no setterinherited
relevant → bool
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
no setterinherited
securityMetadata → SecurityMetadata?
no setterinherited
status → int
no setterinherited
tags → Set<CodeStub>
no setterinherited
valueDate → int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DecryptedHealthElement value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → DecryptedHealthElement
override