HealthElement class sealed

Implemented types
Implementers

Properties

author → String?
final
careTeam → List<CareTeamMember>
no setter
closingDate → int?
final
codes → Set<CodeStub>
final
created → int?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
delegations → Map<String, Set<Delegation>>
final
deletionDate → int?
final
descr → String?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
episodes → List<Episode>
no setter
hashCode → int
The hash code for this object.
no setterinherited
healthElementId → String?
final
id → String
final
idClosingContact → String?
final
identifiers → List<Identifier>
final
idOpeningContact → String?
final
idService → String?
final
laterality → Laterality?
final
medicalLocationId → String?
final
modified → int?
final
note → String?
final
notes → List<Annotation>
final
openingDate → int?
final
plansOfAction → List<PlanOfAction>
no setter
relevant → bool
final
responsible → String?
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final
status → int
final
tags → Set<CodeStub>
final
valueDate → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(HealthElement value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → HealthElement
override