Insurance class abstract

Implemented types
Annotations
  • @freezed

Constructors

Insurance({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new({}) Map<String, String> name, @Default.new(false) bool privateInsurance, @Default.new(false) bool hospitalisationInsurance, @Default.new(false) bool ambulatoryInsurance, @Default.new(null) String? code, @Default.new(null) String? agreementNumber, @Default.new(null) String? parent, required DecryptedAddress address})
const
factory

Properties

address → DecryptedAddress
no setterinherited
agreementNumber → String?
no setterinherited
ambulatoryInsurance → bool
no setterinherited
code → String?
no setterinherited
copyWith → $InsuranceCopyWith<Insurance>
Create a copy of Insurance with the given fields replaced by the non-null parameter values.
no setterinherited
deletionDate → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hospitalisationInsurance → bool
no setterinherited
id → String
no setterinherited
name → Map<String, String>
no setterinherited
parent → String?
no setterinherited
privateInsurance → bool
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Insurance value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Insurance