Invoice class sealed

Implemented types
Implementers

Properties

admissionDate → int?
final
author → String?
final
cancelDate → int?
final
cancelReason → String?
final
careProviderType → String?
final
codes → Set<CodeStub>
final
correctedInvoiceId → String?
final
correctiveInvoiceId → String?
final
created → int?
final
creditNote → bool?
final
creditNoteRelatedInvoiceId → String?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
decisionReference → String?
final
delegations → Map<String, Set<Delegation>>
final
deletionDate → int?
final
encounterLocationName → String?
final
encounterLocationNihii → String?
final
encounterLocationNorm → int?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
error → String?
final
gnotionCdHcParty → String?
final
gnotionFirstName → String?
final
gnotionLastName → String?
final
gnotionNihii → String?
final
gnotionSsin → String?
final
groupId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
idDocument → IdentityDocumentReader?
final
internshipCbe → String?
final
internshipCdHcParty → String?
final
internshipFirstName → String?
final
internshipLastName → String?
final
internshipNihii → String?
final
internshipSsin → String?
final
interventionType → InvoiceInterventionType?
final
invoiceDate → int?
final
invoicePeriod → int?
final
invoiceReference → String?
final
invoiceType → InvoiceType?
final
invoicingCodes → List<InvoicingCode>
no setter
locationNihii → String?
final
locationService → int?
final
longDelayJustification → int?
final
medicalLocationId → String?
final
modified → int?
final
options → Map<String, String>
final
final
payments → List<Payment>?
final
paymentType → PaymentType?
final
printedDate → int?
final
reason → String?
final
receipts → Map<String, String>
final
recipientId → String?
final
recipientType → String?
final
responsible → String?
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final
sentDate → int?
final
sentMediumType → MediumType?
final
supervisorCbe → String?
final
supervisorCdHcParty → String?
final
supervisorFirstName → String?
final
supervisorLastName → String?
final
supervisorNihii → String?
final
supervisorSsin → String?
final
tags → Set<CodeStub>
final
thirdPartyPaymentJustification → String?
final
thirdPartyPaymentReason → String?
final
thirdPartyReference → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Invoice value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Invoice
override