EncryptedMaintenanceTask class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedMaintenanceTask({required String id, @Default.new(null) String? rev, @Default.new([]) List<Identifier> identifier, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) int? deletionDate, @Default.new(null) String? taskType, @Default.new({}) Set<EncryptedPropertyStub> properties, @Default.new(TaskStatus.pending) TaskStatus status, @Default.new({}) Set<String> secretForeignKeys, @Default.new({}) Map<String, Set<Delegation>> cryptedForeignKeys, @Default.new({}) Map<String, Set<Delegation>> delegations, @Default.new({}) Map<String, Set<Delegation>> encryptionKeys, @Default.new(null) Base64String? encryptedSelf, @Default.new(null) SecurityMetadata? securityMetadata})
const
factory

Properties

author → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
copyWith → $EncryptedMaintenanceTaskCopyWith<EncryptedMaintenanceTask>
Create a copy of EncryptedMaintenanceTask with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
cryptedForeignKeys → Map<String, Set<Delegation>>
no setterinherited
delegations → Map<String, Set<Delegation>>
no setterinherited
deletionDate → int?
no setterinherited
encryptedSelf → String?
no setterinherited
encryptionKeys → Map<String, Set<Delegation>>
no setterinherited
endOfLife → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
identifier → List<Identifier>
no setterinherited
medicalLocationId → String?
no setterinherited
modified → int?
no setterinherited
properties → Set<EncryptedPropertyStub>
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
no setterinherited
securityMetadata → SecurityMetadata?
no setterinherited
status → TaskStatus
no setterinherited
tags → Set<CodeStub>
no setterinherited
taskType → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedMaintenanceTask value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedMaintenanceTask
override