DecryptedMessage class abstract

Implemented types
Annotations
  • @freezed

Constructors

DecryptedMessage({required String id, @Default.new(null) String? rev, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) int? deletionDate, @Default.new(null) String? fromAddress, @Default.new(null) String? fromHealthcarePartyId, @Default.new(null) String? formId, @Default.new(null) int? status, @Default.new(null) String? recipientsType, @Default.new({}) Set<String> recipients, @Default.new({}) Set<String> toAddresses, @Default.new(null) int? received, @Default.new(null) int? sent, @Default.new({}) Map<String, String> metas, @Default.new({}) Map<String, MessageReadStatus> readStatus, @Default.new([]) List<MessageAttachment> messageAttachments, @Default.new(null) String? transportGuid, @Default.new(null) String? remark, @Default.new(null) String? conversationGuid, @Default.new(null) String? subject, @Default.new({}) Set<String> invoiceIds, @Default.new(null) String? parentId, @Default.new(null) String? externalRef, @Default.new({}) Set<String> unassignedResults, @Default.new({}) Map<String, String> assignedResults, @Default.new({}) Map<String, String> senderReferences, @Default.new({}) Set<String> secretForeignKeys, @Default.new({}) Map<String, Set<Delegation>> cryptedForeignKeys, @Default.new({}) Map<String, Set<Delegation>> delegations, @Default.new({}) Map<String, Set<Delegation>> encryptionKeys, @Default.new(null) Base64String? encryptedSelf, @Default.new(null) SecurityMetadata? securityMetadata})
const
factory

Properties

assignedResults → Map<String, String>
no setterinherited
author → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
conversationGuid → String?
no setterinherited
copyWith → $DecryptedMessageCopyWith<DecryptedMessage>
Create a copy of DecryptedMessage with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
cryptedForeignKeys → Map<String, Set<Delegation>>
no setterinherited
delegations → Map<String, Set<Delegation>>
no setterinherited
deletionDate → int?
no setterinherited
encryptedSelf → String?
no setterinherited
encryptionKeys → Map<String, Set<Delegation>>
no setterinherited
endOfLife → int?
no setterinherited
externalRef → String?
no setterinherited
formId → String?
no setterinherited
fromAddress → String?
no setterinherited
fromHealthcarePartyId → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
invoiceIds → Set<String>
no setterinherited
medicalLocationId → String?
no setterinherited
messageAttachments → List<MessageAttachment>
no setterinherited
metas → Map<String, String>
no setterinherited
modified → int?
no setterinherited
parentId → String?
no setterinherited
readStatus → Map<String, MessageReadStatus>
no setterinherited
received → int?
no setterinherited
recipients → Set<String>
no setterinherited
recipientsType → String?
no setterinherited
remark → String?
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
no setterinherited
securityMetadata → SecurityMetadata?
no setterinherited
senderReferences → Map<String, String>
no setterinherited
sent → int?
no setterinherited
status → int?
no setterinherited
subject → String?
no setterinherited
tags → Set<CodeStub>
no setterinherited
toAddresses → Set<String>
no setterinherited
transportGuid → String?
no setterinherited
unassignedResults → Set<String>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DecryptedMessage value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → DecryptedMessage
override