Message class sealed

Implemented types
Implementers

Properties

assignedResults → Map<String, String>
final
author → String?
final
codes → Set<CodeStub>
final
conversationGuid → String?
final
created → int?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
delegations → Map<String, Set<Delegation>>
final
deletionDate → int?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
externalRef → String?
final
formId → String?
final
fromAddress → String?
final
fromHealthcarePartyId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
invoiceIds → Set<String>
final
medicalLocationId → String?
final
messageAttachments → List<MessageAttachment>
final
metas → Map<String, String>
final
modified → int?
final
parentId → String?
final
readStatus → Map<String, MessageReadStatus>
final
received → int?
final
recipients → Set<String>
final
recipientsType → String?
final
remark → String?
final
responsible → String?
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final
senderReferences → Map<String, String>
final
sent → int?
final
status → int?
final
subject → String?
final
tags → Set<CodeStub>
final
toAddresses → Set<String>
final
transportGuid → String?
final
unassignedResults → Set<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Message value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Message
override