EncryptedPatient class abstract

Implemented types
Annotations
  • @freezed

Constructors

EncryptedPatient({required String id, @Default.new([]) List<Identifier> identifier, @Default.new(null) String? rev, @Default.new(null) int? created, @Default.new(null) int? modified, @Default.new(null) String? author, @Default.new(null) String? responsible, @Default.new({}) Set<CodeStub> tags, @Default.new({}) Set<CodeStub> codes, @Default.new(null) int? endOfLife, @Default.new(null) int? deletionDate, @Default.new(null) String? firstName, @Default.new(null) String? lastName, @Default.new([]) List<PersonName> names, @Default.new(null) String? companyName, @Default.new([]) List<HexString> languages, @Default.new([]) List<EncryptedAddress> addresses, @Default.new(null) String? civility, @Default.new(Gender.unknown) Gender? gender, @Default.new(Gender.unknown) Gender? birthSex, @Default.new(null) String? mergeToPatientId, @Default.new({}) Set<String> mergedIds, @Default.new(null) String? alias, @Default.new(true) bool active, @Default.new(DeactivationReason.none) DeactivationReason deactivationReason, @Default.new(null) int? deactivationDate, @Default.new(null) String? ssin, @Default.new(null) String? maidenName, @Default.new(null) String? spouseName, @Default.new(null) String? partnerName, @Default.new(PersonalStatus.unknown) PersonalStatus? personalStatus, @Default.new(null) int? dateOfBirth, @Default.new(null) int? dateOfDeath, @Default.new(null) int? timestampOfLatestEidReading, @Default.new(null) String? placeOfBirth, @Default.new(null) String? placeOfDeath, @Default.new(null) bool? deceased, @Default.new(null) String? education, @Default.new(null) String? profession, @Default.new([]) List<Annotation> notes, @Default.new(null) String? note, @Default.new(null) String? administrativeNote, @Default.new(null) String? nationality, @Default.new(null) String? race, @Default.new(null) String? ethnicity, @Default.new(null) String? preferredUserId, @Default.new(null) Uint8List? picture, @Default.new(null) String? externalId, @Default.new([]) List<EncryptedInsurability> insurabilities, @Default.new([]) List<Partnership> partnerships, @Default.new([]) List<EncryptedPatientHealthCareParty> patientHealthCareParties, @Default.new([]) List<EncryptedFinancialInstitutionInformation> financialInstitutionInformation, @Default.new([]) List<EncryptedMedicalHouseContract> medicalHouseContracts, @Default.new([]) List<CodeStub> patientProfessions, @Default.new({}) Map<String, List<HexString>> parameters, @Default.new({}) Set<EncryptedPropertyStub> properties, @Default.new({}) Map<String, List<HexString>> hcPartyKeys, @Default.new({}) Map<AesExchangeKeyEntryKeyString, Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>> aesExchangeKeys, @Default.new({}) Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>> transferKeys, @Default.new({}) Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString> privateKeyShamirPartitions, @Default.new(null) CardinalRsaPublicKey? publicKey, @Default.new({}) Set<CardinalRsaPublicKey> publicKeysForOaepWithSha256, @Default.new({}) Set<String> secretForeignKeys, @Default.new({}) Map<String, Set<Delegation>> cryptedForeignKeys, @Default.new({}) Map<String, Set<Delegation>> delegations, @Default.new({}) Map<String, Set<Delegation>> encryptionKeys, @Default.new(null) Base64String? encryptedSelf, @Default.new(null) SecurityMetadata? securityMetadata, @Default.new(null) Set<DecryptedPropertyStub>? cryptoActorProperties, @Default.new(null) String? medicalLocationId, @Default.new({}) Set<String> nonDuplicateIds, @Default.new({}) Set<String> encryptedAdministrativesDocuments, @Default.new(null) String? comment, @Default.new(null) String? warning, @Default.new(null) CodeStub? fatherBirthCountry, @Default.new(null) CodeStub? birthCountry, @Default.new(null) CodeStub? nativeCountry, @Default.new(null) CodeStub? socialStatus, @Default.new(null) CodeStub? mainSourceOfIncome, @Default.new([]) List<EncryptedSchoolingInfo> schoolingInfos, @Default.new([]) List<EncryptedEmploymentInfo> employementInfos, @Default.new(null) Never parentId})
const
factory

Properties

active → bool
no setterinherited
addresses → List<EncryptedAddress>
no setterinherited
administrativeNote → String?
no setterinherited
aesExchangeKeys → Map<AesExchangeKeyEntryKeyString, Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>>
no setterinherited
alias → String?
no setterinherited
author → String?
no setterinherited
birthCountry → CodeStub?
no setterinherited
birthSex → Gender?
no setterinherited
civility → String?
no setterinherited
codes → Set<CodeStub>
no setterinherited
comment → String?
no setterinherited
companyName → String?
no setterinherited
copyWith → $EncryptedPatientCopyWith<EncryptedPatient>
Create a copy of EncryptedPatient with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
cryptedForeignKeys → Map<String, Set<Delegation>>
no setterinherited
cryptoActorProperties → Set<DecryptedPropertyStub>?
no setterinherited
dateOfBirth → int?
no setterinherited
dateOfDeath → int?
no setterinherited
deactivationDate → int?
no setterinherited
deactivationReason → DeactivationReason
no setterinherited
deceased → bool?
no setterinherited
delegations → Map<String, Set<Delegation>>
no setterinherited
deletionDate → int?
no setterinherited
education → String?
no setterinherited
employementInfos → List<EncryptedEmploymentInfo>
no setterinherited
encryptedAdministrativesDocuments → Set<String>
no setterinherited
encryptedSelf → String?
no setterinherited
encryptionKeys → Map<String, Set<Delegation>>
no setterinherited
endOfLife → int?
no setterinherited
ethnicity → String?
no setterinherited
externalId → String?
no setterinherited
fatherBirthCountry → CodeStub?
no setterinherited
financialInstitutionInformation → List<EncryptedFinancialInstitutionInformation>
no setterinherited
firstName → String?
no setterinherited
gender → Gender?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hcPartyKeys → Map<String, List<HexString>>
no setterinherited
id → String
no setterinherited
identifier → List<Identifier>
no setterinherited
insurabilities → List<EncryptedInsurability>
no setterinherited
languages → List<HexString>
no setterinherited
lastName → String?
no setterinherited
maidenName → String?
no setterinherited
mainSourceOfIncome → CodeStub?
no setterinherited
medicalHouseContracts → List<EncryptedMedicalHouseContract>
no setterinherited
medicalLocationId → String?
no setterinherited
mergedIds → Set<String>
no setterinherited
mergeToPatientId → String?
no setterinherited
modified → int?
no setterinherited
names → List<PersonName>
no setterinherited
nationality → String?
no setterinherited
nativeCountry → CodeStub?
no setterinherited
nonDuplicateIds → Set<String>
no setterinherited
note → String?
no setterinherited
notes → List<Annotation>
no setterinherited
parameters → Map<String, List<HexString>>
no setterinherited
parentId → Never
no setterinherited
partnerName → String?
no setterinherited
partnerships → List<Partnership>
no setterinherited
patientHealthCareParties → List<EncryptedPatientHealthCareParty>
no setterinherited
patientProfessions → List<CodeStub>
no setterinherited
personalStatus → PersonalStatus?
no setterinherited
picture → Uint8List?
no setterinherited
placeOfBirth → String?
no setterinherited
placeOfDeath → String?
no setterinherited
preferredUserId → String?
no setterinherited
privateKeyShamirPartitions → Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>
no setterinherited
profession → String?
no setterinherited
properties → Set<EncryptedPropertyStub>
no setterinherited
publicKey → CardinalRsaPublicKey?
no setterinherited
publicKeysForOaepWithSha256 → Set<CardinalRsaPublicKey>
no setterinherited
race → String?
no setterinherited
responsible → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schoolingInfos → List<EncryptedSchoolingInfo>
no setterinherited
secretForeignKeys → Set<String>
no setterinherited
securityMetadata → SecurityMetadata?
no setterinherited
socialStatus → CodeStub?
no setterinherited
spouseName → String?
no setterinherited
ssin → String?
no setterinherited
tags → Set<CodeStub>
no setterinherited
timestampOfLatestEidReading → int?
no setterinherited
transferKeys → Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>
no setterinherited
warning → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedPatient value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → EncryptedPatient
override