Patient class sealed

Implemented types
Implementers

Properties

active → bool
final
addresses → List<Address>
no setteroverride
administrativeNote → String?
final
aesExchangeKeys → Map<AesExchangeKeyEntryKeyString, Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>>
final
alias → String?
final
author → String?
final
birthCountry → CodeStub?
final
birthSex → Gender?
final
civility → String?
final
codes → Set<CodeStub>
final
comment → String?
final
companyName → String?
final
created → int?
final
cryptedForeignKeys → Map<String, Set<Delegation>>
final
cryptoActorProperties → Set<DecryptedPropertyStub>?
final
dateOfBirth → int?
final
dateOfDeath → int?
final
deactivationDate → int?
final
deactivationReason → DeactivationReason
final
deceased → bool?
final
delegations → Map<String, Set<Delegation>>
final
deletionDate → int?
final
education → String?
final
employementInfos → List<EmploymentInfo>
no setter
encryptedAdministrativesDocuments → Set<String>
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
endOfLife → int?
final
ethnicity → String?
final
externalId → String?
final
fatherBirthCountry → CodeStub?
final
financialInstitutionInformation → List<FinancialInstitutionInformation>
no setter
firstName → String?
final
gender → Gender?
final
hashCode → int
The hash code for this object.
no setterinherited
hcPartyKeys → Map<String, List<HexString>>
final
id → String
final
identifier → List<Identifier>
final
insurabilities → List<Insurability>
no setter
languages → List<HexString>
final
lastName → String?
final
maidenName → String?
final
mainSourceOfIncome → CodeStub?
final
medicalHouseContracts → List<MedicalHouseContract>
no setter
medicalLocationId → String?
final
mergedIds → Set<String>
final
mergeToPatientId → String?
final
modified → int?
final
names → List<PersonName>
final
nationality → String?
final
nativeCountry → CodeStub?
final
nonDuplicateIds → Set<String>
final
note → String?
final
notes → List<Annotation>
final
parameters → Map<String, List<HexString>>
final
parentId → Never
final
partnerName → String?
final
partnerships → List<Partnership>
final
patientHealthCareParties → List<PatientHealthCareParty>
no setter
patientProfessions → List<CodeStub>
final
personalStatus → PersonalStatus?
final
picture → Uint8List?
final
placeOfBirth → String?
final
placeOfDeath → String?
final
preferredUserId → String?
final
privateKeyShamirPartitions → Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>
final
profession → String?
final
properties → Set<PropertyStub>
no setter
publicKey → CardinalRsaPublicKey?
final
publicKeysForOaepWithSha256 → Set<CardinalRsaPublicKey>
final
race → String?
final
responsible → String?
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schoolingInfos → List<SchoolingInfo>
no setter
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final
socialStatus → CodeStub?
final
spouseName → String?
final
ssin → String?
final
tags → Set<CodeStub>
final
timestampOfLatestEidReading → int?
final
transferKeys → Map<String, Map<AesExchangeKeyEncryptionKeypairIdentifier, HexString>>
final
warning → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Patient value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → Patient
override