Place class abstract

Implemented types
Annotations
  • @freezed

Constructors

Place({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new(null) String? name, @Default.new(null) DecryptedAddress? address})
const
factory

Properties

address → DecryptedAddress?
no setterinherited
copyWith → $PlaceCopyWith<Place>
Create a copy of Place with the given fields replaced by the non-null parameter values.
no setterinherited
deletionDate → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
name → String?
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(Place value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → Place