ReplicationInfo class abstract

Annotations
  • @freezed

Constructors

ReplicationInfo({@Default.new(false) bool active, @Default.new(false) bool running, @Default.new(null) int? pendingFrom, @Default.new(null) int? pendingTo})
const
factory

Properties

active → bool
no setterinherited
copyWith → $ReplicationInfoCopyWith<ReplicationInfo>
Create a copy of ReplicationInfo with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pendingFrom → int?
no setterinherited
pendingTo → int?
no setterinherited
running → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(ReplicationInfo value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → ReplicationInfo