DecryptedSecureDelegationKeyMap class abstract

Implemented types
Annotations
  • @freezed

Constructors

DecryptedSecureDelegationKeyMap({required String id, @Default.new(null) String? rev, required String delegationKey, @Default.new(null) String? delegator, @Default.new(null) String? delegate, @Default.new({}) Set<String> secretForeignKeys, @Default.new({}) Map<String, Set<Delegation>> cryptedForeignKeys, @Default.new({}) Map<String, Set<Delegation>> delegations, @Default.new({}) Map<String, Set<Delegation>> encryptionKeys, @Default.new(null) Base64String? encryptedSelf, @Default.new(null) SecurityMetadata? securityMetadata, @Default.new(null) int? deletionDate})
const
factory

Properties

copyWith → $DecryptedSecureDelegationKeyMapCopyWith<DecryptedSecureDelegationKeyMap>
Create a copy of DecryptedSecureDelegationKeyMap with the given fields replaced by the non-null parameter values.
no setterinherited
cryptedForeignKeys → Map<String, Set<Delegation>>
no setterinherited
delegate → String?
no setterinherited
delegationKey → String
no setterinherited
delegations → Map<String, Set<Delegation>>
no setterinherited
delegator → String?
no setterinherited
deletionDate → int?
no setterinherited
encryptedSelf → String?
no setterinherited
encryptionKeys → Map<String, Set<Delegation>>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
rev → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
no setterinherited
securityMetadata → SecurityMetadata?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(DecryptedSecureDelegationKeyMap value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → DecryptedSecureDelegationKeyMap
override