SecureDelegationKeyMap class sealed

Implemented types
Implementers

Properties

cryptedForeignKeys → Map<String, Set<Delegation>>
final
delegate → String?
final
delegationKey → String
final
delegations → Map<String, Set<Delegation>>
final
delegator → String?
final
deletionDate → int?
final
encryptedSelf → String?
final
encryptionKeys → Map<String, Set<Delegation>>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
rev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretForeignKeys → Set<String>
final
securityMetadata → SecurityMetadata?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(SecureDelegationKeyMap value) → Map<String, dynamic>
override
fromJSON(Map<String, dynamic> data) → SecureDelegationKeyMap
override