AuthenticationToken class abstract

Annotations
  • @freezed

Constructors

AuthenticationToken({@Default.new(null) String? token, required int creationTime, required int validity, @Default.new(null) int? deletionDate})
const
factory

Properties

copyWith → $AuthenticationTokenCopyWith<AuthenticationToken>
Create a copy of AuthenticationToken with the given fields replaced by the non-null parameter values.
no setterinherited
creationTime → int
no setterinherited
deletionDate → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String?
no setterinherited
validity → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(AuthenticationToken value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → AuthenticationToken