User class abstract

Implemented types
Annotations
  • @freezed

Constructors

User({required String id, @Default.new(null) String? rev, @Default.new(null) int? deletionDate, @Default.new(null) int? created, @Default.new([]) List<Identifier> identifier, @Default.new(null) String? name, @Default.new({}) Set<DecryptedPropertyStub> properties, @Default.new({}) Set<Permission> permissions, @Default.new({}) Set<String> roles, @Default.new(null) UsersType? type, @Default.new(null) UsersStatus? status, @Default.new(null) String? login, @Default.new(null) String? passwordHash, @Default.new(null) String? groupId, @Default.new(null) String? healthcarePartyId, @Default.new(null) String? patientId, @Default.new(null) String? deviceId, @Default.new({}) Map<DelegationTag, Set<String>> autoDelegations, @Default.new(null) DateTime? createdDate, @Default.new(null) DateTime? termsOfUseDate, @Default.new(null) String? email, @Default.new(null) String? mobilePhone, @Default.new({}) Map<String, String> applicationTokens, @Default.new({}) Map<String, AuthenticationToken> authenticationTokens, @Default.new(null) UserSystemMetadata? systemMetadata})
const
factory

Properties

applicationTokens → Map<String, String>
no setterinherited
authenticationTokens → Map<String, AuthenticationToken>
no setterinherited
autoDelegations → Map<DelegationTag, Set<String>>
no setterinherited
copyWith → $UserCopyWith<User>
Create a copy of User with the given fields replaced by the non-null parameter values.
no setterinherited
created → int?
no setterinherited
createdDate → DateTime?
no setterinherited
deletionDate → int?
no setterinherited
deviceId → String?
no setterinherited
email → String?
no setterinherited
groupId → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
healthcarePartyId → String?
no setterinherited
id → String
no setterinherited
identifier → List<Identifier>
no setterinherited
login → String?
no setterinherited
mobilePhone → String?
no setterinherited
name → String?
no setterinherited
passwordHash → String?
no setterinherited
patientId → String?
no setterinherited
permissions → Set<Permission>
no setterinherited
properties → Set<DecryptedPropertyStub>
no setterinherited
rev → String?
no setterinherited
roles → Set<String>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → UsersStatus?
no setterinherited
systemMetadata → UserSystemMetadata?
no setterinherited
termsOfUseDate → DateTime?
no setterinherited
type → UsersType?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(User value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → User