EncryptedFieldsConfiguration class

Constructors

EncryptedFieldsConfiguration({Set<String> accessLog = const {"detail", "objectId", "patientId"}, Set<String> calendarItem = const {"details", "title", "patientId", "phoneNumber", "address", "addressText", "meetingTags[].*", "flowItem"}, Set<String> contact = const {"descr", "notes[].markdown", "location", "encounterLocation", "participants"}, Set<String> service = const {"notes[].markdown", "comment"}, Set<String> healthElement = const {"descr", "note", "notes[].markdown", "careTeam[].*", "episode[].name", "episode[].comment"}, Set<String> maintenanceTask = const {"properties"}, Set<String> patient = const {"note", "notes[].markdown", "created", "modified", "companyName", "languages", "civility", "birthSex", "personalStatus", "nationality", "race", "ethnicity", "picture", "insurabilities[].*", "partnerships[].*", "patientHealthCareParties[].*", "financialInstitutionInformation[].*", "medicalHouseContracts[].*", "patientProfessions", "comment", "warning", "fatherBirthCountry", "birthCountry", "nativeCountry", "socialStatus", "mainSourceOfIncome", "schoolingInfos[].*", "employementInfos[].*"}, Set<String> message = const {"subject"}, Set<String> topic = const {"description", "linkedServices", "linkedHealthElements"}, Set<String> document = const {"medicalLocationId", "name"}, Set<String> form = const {"descr"}, Set<String> receipt = const {"references"}, Set<String> classification = const {"label"}, Set<String> timeTable = const {}, Set<String> invoice = const {"reason"}})
const

Properties

accessLog → Set<String>
final
calendarItem → Set<String>
final
classification → Set<String>
final
contact → Set<String>
final
document → Set<String>
final
form → Set<String>
final
hashCode → int
The hash code for this object.
no setterinherited
healthElement → Set<String>
final
invoice → Set<String>
final
maintenanceTask → Set<String>
final
message → Set<String>
final
patient → Set<String>
final
receipt → Set<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → Set<String>
final
timeTable → Set<String>
final
topic → Set<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EncryptedFieldsConfiguration value) → Map<String, dynamic>