AgendaInGroupPlatformApi class

Constructors

AgendaInGroupPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAgenda(String sdkId, GroupScoped<Agenda> entity) → Future<GroupScoped<Agenda>>
deleteAgenda(String sdkId, GroupScoped<Agenda> agenda) → Future<GroupScoped<StoredDocumentIdentifier>>
deleteAgendaById(String sdkId, GroupScoped<StoredDocumentIdentifier> entityId) → Future<GroupScoped<StoredDocumentIdentifier>>
deleteAgendas(String sdkId, List<GroupScoped<Agenda>> agendas) → Future<List<GroupScoped<StoredDocumentIdentifier>>>
deleteAgendasByIds(String sdkId, List<GroupScoped<StoredDocumentIdentifier>> entityIds) → Future<List<GroupScoped<StoredDocumentIdentifier>>>
filterAgendasBy(String sdkId, String groupId, BaseFilterOptions<Agenda> filter) → Future<PaginatedListIterator<GroupScoped<Agenda>>>
filterAgendasBySorted(String sdkId, String groupId, BaseSortableFilterOptions<Agenda> filter) → Future<PaginatedListIterator<GroupScoped<Agenda>>>
getAgenda(String sdkId, String groupId, String entityId) → Future<GroupScoped<Agenda>?>
getAgendas(String sdkId, String groupId, List<String> entityIds) → Future<List<GroupScoped<Agenda>>>
matchAgendasBy(String sdkId, String groupId, BaseFilterOptions<Agenda> filter) → Future<List<String>>
matchAgendasBySorted(String sdkId, String groupId, BaseSortableFilterOptions<Agenda> filter) → Future<List<String>>
modifyAgenda(String sdkId, GroupScoped<Agenda> entity) → Future<GroupScoped<Agenda>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited