CalendarItemBasicInGroupPlatformApi class

Constructors

CalendarItemBasicInGroupPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createCalendarItem(String sdkId, GroupScoped<EncryptedCalendarItem> entity) → Future<GroupScoped<EncryptedCalendarItem>>
deleteCalendarItem(String sdkId, GroupScoped<CalendarItem> calendarItem) → Future<GroupScoped<StoredDocumentIdentifier>>
deleteCalendarItemById(String sdkId, GroupScoped<StoredDocumentIdentifier> entityId) → Future<GroupScoped<StoredDocumentIdentifier>>
deleteCalendarItems(String sdkId, List<GroupScoped<CalendarItem>> calendarItems) → Future<List<GroupScoped<StoredDocumentIdentifier>>>
deleteCalendarItemsByIds(String sdkId, List<GroupScoped<StoredDocumentIdentifier>> entityIds) → Future<List<GroupScoped<StoredDocumentIdentifier>>>
filterCalendarItemsBy(String sdkId, String groupId, BaseFilterOptions<CalendarItem> filter) → Future<PaginatedListIterator<GroupScoped<EncryptedCalendarItem>>>
filterCalendarItemsBySorted(String sdkId, String groupId, BaseSortableFilterOptions<CalendarItem> filter) → Future<PaginatedListIterator<GroupScoped<EncryptedCalendarItem>>>
getCalendarItem(String sdkId, String groupId, String entityId) → Future<GroupScoped<EncryptedCalendarItem>?>
getCalendarItems(String sdkId, String groupId, List<String> entityIds) → Future<List<GroupScoped<EncryptedCalendarItem>>>
matchCalendarItemsBy(String sdkId, String groupId, BaseFilterOptions<CalendarItem> filter) → Future<List<String>>
matchCalendarItemsBySorted(String sdkId, String groupId, BaseSortableFilterOptions<CalendarItem> filter) → Future<List<String>>
modifyCalendarItem(String sdkId, GroupScoped<EncryptedCalendarItem> entity) → Future<GroupScoped<EncryptedCalendarItem>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited