CalendarItemInGroupPlatformApi class

Constructors

CalendarItemInGroupPlatformApi(MethodChannel _methodChannel)

Properties

encrypted ↔ CalendarItemInGroupEncryptedPlatformApi
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover ↔ CalendarItemInGroupTryAndRecoverPlatformApi
getter/setter pair

Methods

createCalendarItem(String sdkId, GroupScoped<DecryptedCalendarItem> entity) → Future<GroupScoped<DecryptedCalendarItem>>
createDelegationDeAnonymizationMetadata(String sdkId, GroupScoped<CalendarItem> entity, Set<EntityReferenceInGroup> delegates) → Future<void>
decrypt(String sdkId, List<GroupScoped<EncryptedCalendarItem>> calendarItems) → Future<List<GroupScoped<DecryptedCalendarItem>>>
decryptPatientIdOf(String sdkId, GroupScoped<CalendarItem> calendarItem) → Future<Set<EntityReferenceInGroup>>
deleteCalendarItem(String sdkId, GroupScoped<CalendarItem> calendarItem) → Future<GroupScoped<StoredDocumentIdentifier>>
deleteCalendarItemById(String sdkId, GroupScoped<StoredDocumentIdentifier> entityId) → Future<GroupScoped<StoredDocumentIdentifier>>
deleteCalendarItems(String sdkId, List<GroupScoped<CalendarItem>> calendarItems) → Future<List<GroupScoped<StoredDocumentIdentifier>>>
deleteCalendarItemsByIds(String sdkId, List<GroupScoped<StoredDocumentIdentifier>> entityIds) → Future<List<GroupScoped<StoredDocumentIdentifier>>>
encryptOrValidate(String sdkId, List<GroupScoped<CalendarItem>> calendarItems) → Future<List<GroupScoped<EncryptedCalendarItem>>>
filterCalendarItemsBy(String sdkId, String groupId, FilterOptions<CalendarItem> filter) → Future<PaginatedListIterator<GroupScoped<DecryptedCalendarItem>>>
filterCalendarItemsBySorted(String sdkId, String groupId, SortableFilterOptions<CalendarItem> filter) → Future<PaginatedListIterator<GroupScoped<DecryptedCalendarItem>>>
getCalendarItem(String sdkId, String groupId, String entityId) → Future<GroupScoped<DecryptedCalendarItem>?>
getCalendarItems(String sdkId, String groupId, List<String> entityIds) → Future<List<GroupScoped<DecryptedCalendarItem>>>
getEncryptionKeysOf(String sdkId, GroupScoped<CalendarItem> calendarItem) → Future<Set<String>>
hasWriteAccess(String sdkId, GroupScoped<CalendarItem> calendarItem) → Future<bool>
matchCalendarItemsBy(String sdkId, String groupId, FilterOptions<CalendarItem> filter) → Future<List<String>>
matchCalendarItemsBySorted(String sdkId, String groupId, SortableFilterOptions<CalendarItem> filter) → Future<List<String>>
modifyCalendarItem(String sdkId, GroupScoped<DecryptedCalendarItem> entity) → Future<GroupScoped<DecryptedCalendarItem>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String sdkId, EntityReferenceInGroup delegate, GroupScoped<DecryptedCalendarItem> calendarItem, CalendarItemShareOptions? options) → Future<GroupScoped<DecryptedCalendarItem>>
shareWithMany(String sdkId, GroupScoped<DecryptedCalendarItem> calendarItem, Map<EntityReferenceInGroup, CalendarItemShareOptions> delegates) → Future<GroupScoped<DecryptedCalendarItem>>
toString() → String
A string representation of this object.
inherited
tryDecrypt(String sdkId, List<GroupScoped<EncryptedCalendarItem>> calendarItems) → Future<List<GroupScoped<CalendarItem>>>
withEncryptionMetadata(String sdkId, String entityGroupId, DecryptedCalendarItem? base, GroupScoped<Patient>? patient, User? user, Map<EntityReferenceInGroup, AccessLevel> delegates, SecretIdUseOption secretId) → Future<GroupScoped<DecryptedCalendarItem>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited