CalendarItemPlatformApi class

Constructors

CalendarItemPlatformApi(MethodChannel _methodChannel)

Properties

encrypted ↔ CalendarItemEncryptedPlatformApi
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inGroup ↔ CalendarItemInGroupPlatformApi
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover ↔ CalendarItemTryAndRecoverPlatformApi
getter/setter pair

Methods

createCalendarItem(String sdkId, DecryptedCalendarItem entity) → Future<DecryptedCalendarItem>
createDelegationDeAnonymizationMetadata(String sdkId, CalendarItem entity, Set<String> delegates) → Future<void>
decrypt(String sdkId, List<EncryptedCalendarItem> calendarItems) → Future<List<DecryptedCalendarItem>>
decryptPatientIdOf(String sdkId, CalendarItem calendarItem) → Future<Set<EntityReferenceInGroup>>
deleteCalendarItem(String sdkId, CalendarItem calendarItem) → Future<StoredDocumentIdentifier>
deleteCalendarItemById(String sdkId, String entityId, String rev) → Future<StoredDocumentIdentifier>
deleteCalendarItems(String sdkId, List<CalendarItem> calendarItems) → Future<List<StoredDocumentIdentifier>>
deleteCalendarItemsByIds(String sdkId, List<StoredDocumentIdentifier> entityIds) → Future<List<StoredDocumentIdentifier>>
encryptOrValidate(String sdkId, List<CalendarItem> calendarItems) → Future<List<EncryptedCalendarItem>>
filterCalendarItemsBy(String sdkId, FilterOptions<CalendarItem> filter) → Future<PaginatedListIterator<DecryptedCalendarItem>>
filterCalendarItemsBySorted(String sdkId, SortableFilterOptions<CalendarItem> filter) → Future<PaginatedListIterator<DecryptedCalendarItem>>
getCalendarItem(String sdkId, String entityId) → Future<DecryptedCalendarItem?>
getCalendarItems(String sdkId, List<String> entityIds) → Future<List<DecryptedCalendarItem>>
getEncryptionKeysOf(String sdkId, CalendarItem calendarItem) → Future<Set<String>>
hasWriteAccess(String sdkId, CalendarItem calendarItem) → Future<bool>
linkToPatient(String sdkId, CalendarItem calendarItem, Patient patient, Set<String> shareLinkWithDelegates) → Future<DecryptedCalendarItem>
matchCalendarItemsBy(String sdkId, FilterOptions<CalendarItem> filter) → Future<List<String>>
matchCalendarItemsBySorted(String sdkId, SortableFilterOptions<CalendarItem> filter) → Future<List<String>>
modifyCalendarItem(String sdkId, DecryptedCalendarItem entity) → Future<DecryptedCalendarItem>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeCalendarItem(String sdkId, CalendarItem calendarItem) → Future<void>
purgeCalendarItemById(String sdkId, String id, String rev) → Future<void>
shareWith(String sdkId, String delegateId, DecryptedCalendarItem calendarItem, CalendarItemShareOptions? options) → Future<DecryptedCalendarItem>
shareWithMany(String sdkId, DecryptedCalendarItem calendarItem, Map<String, CalendarItemShareOptions> delegates) → Future<DecryptedCalendarItem>
subscribeToEvents(String sdkId, Set<SubscriptionEventType> events, FilterOptions<CalendarItem> filter, EntitySubscriptionConfiguration? subscriptionConfig) → Future<EntitySubscription<EncryptedCalendarItem>>
toString() → String
A string representation of this object.
inherited
tryDecrypt(String sdkId, List<EncryptedCalendarItem> calendarItems) → Future<List<CalendarItem>>
undeleteCalendarItem(String sdkId, CalendarItem calendarItem) → Future<DecryptedCalendarItem>
undeleteCalendarItemById(String sdkId, String id, String rev) → Future<DecryptedCalendarItem>
withEncryptionMetadata(String sdkId, DecryptedCalendarItem? base, Patient? patient, User? user, Map<String, AccessLevel> delegates, SecretIdUseOption secretId) → Future<DecryptedCalendarItem>

Operators

operator ==(Object other) → bool
The equality operator.
inherited