CardinalSdkPlatformApisPlugin class abstract

Implementers

Properties

accessLog → AccessLogPlatformApi
no setter
accessLogBasic → AccessLogBasicPlatformApi
no setter
agenda → AgendaPlatformApi
no setter
applicationSettings → ApplicationSettingsPlatformApi
no setter
auth → AuthPlatformApi
no setter
calendarItem → CalendarItemPlatformApi
no setter
calendarItemBasic → CalendarItemBasicPlatformApi
no setter
calendarItemType → CalendarItemTypePlatformApi
no setter
cardinalMaintenanceTask → CardinalMaintenanceTaskPlatformApi
no setter
classification → ClassificationPlatformApi
no setter
classificationBasic → ClassificationBasicPlatformApi
no setter
code → CodePlatformApi
no setter
contact → ContactPlatformApi
no setter
contactBasic → ContactBasicPlatformApi
no setter
crypto → CryptoPlatformApi
no setter
dataOwner → DataOwnerPlatformApi
no setter
device → DevicePlatformApi
no setter
document → DocumentPlatformApi
no setter
documentBasic → DocumentBasicPlatformApi
no setter
documentTemplate → DocumentTemplatePlatformApi
no setter
entityReference → EntityReferencePlatformApi
no setter
entityTemplate → EntityTemplatePlatformApi
no setter
form → FormPlatformApi
no setter
formBasic → FormBasicPlatformApi
no setter
frontEndMigration → FrontEndMigrationPlatformApi
no setter
group → GroupPlatformApi
no setter
hashCode → int
The hash code for this object.
no setterinherited
healthcareParty → HealthcarePartyPlatformApi
no setter
healthElement → HealthElementPlatformApi
no setter
healthElementBasic → HealthElementBasicPlatformApi
no setter
insurance → InsurancePlatformApi
no setter
invoice → InvoicePlatformApi
no setter
invoiceBasic → InvoiceBasicPlatformApi
no setter
keyword → KeywordPlatformApi
no setter
maintenanceTask → MaintenanceTaskPlatformApi
no setter
maintenanceTaskBasic → MaintenanceTaskBasicPlatformApi
no setter
medicalLocation → MedicalLocationPlatformApi
no setter
message → MessagePlatformApi
no setter
messageBasic → MessageBasicPlatformApi
no setter
patient → PatientPlatformApi
no setter
patientBasic → PatientBasicPlatformApi
no setter
permission → PermissionPlatformApi
no setter
place → PlacePlatformApi
no setter
receipt → ReceiptPlatformApi
no setter
receiptBasic → ReceiptBasicPlatformApi
no setter
recovery → RecoveryPlatformApi
no setter
role → RolePlatformApi
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shamirKeysManager → ShamirKeysManagerPlatformApi
no setter
system → SystemPlatformApi
no setter
tarification → TarificationPlatformApi
no setter
timeTable → TimeTablePlatformApi
no setter
topic → TopicPlatformApi
no setter
topicBasic → TopicBasicPlatformApi
no setter
user → UserPlatformApi
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited