CodePlatformApi class

Constructors

CodePlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createCode(String sdkId, Code c) → Future<Code>
createCodes(String sdkId, List<Code> codeBatch) → Future<List<Code>>
createCodesInGroup(String sdkId, String groupId, List<Code> codeBatch) → Future<List<Code>>
filterCodesBy(String sdkId, BaseFilterOptions<Code> filter) → Future<PaginatedListIterator<Code>>
filterCodesBySorted(String sdkId, BaseSortableFilterOptions<Code> filter) → Future<PaginatedListIterator<Code>>
getCode(String sdkId, String codeId) → Future<Code?>
getCodeByRegionLanguageTypeLabel(String sdkId, String region, String label, String type, String? languages) → Future<Code?>
getCodes(String sdkId, List<String> codeIds) → Future<List<Code>>
getCodesInGroup(String sdkId, String groupId, List<String> codeIds) → Future<List<Code>>
getCodeWithParts(String sdkId, String type, String code, String version) → Future<Code?>
importCodes(String sdkId, String codeType) → Future<void>
isCodeValid(String sdkId, String type, String code, String? version) → Future<BooleanResponse>
listCodesByRegionTypeCodeVersion(String sdkId, String region, String? type, String? code, String? version) → Future<List<Code>>
listCodeTypesBy(String sdkId, String? region, String? type) → Future<List<String>>
listTagTypesBy(String sdkId, String? region, String? type) → Future<List<String>>
matchCodesBy(String sdkId, BaseFilterOptions<Code> filter) → Future<List<String>>
matchCodesBySorted(String sdkId, BaseSortableFilterOptions<Code> filter) → Future<List<String>>
modifyCode(String sdkId, Code codeDto) → Future<Code>
modifyCodes(String sdkId, List<Code> codeBatch) → Future<List<Code>>
modifyCodesInGroup(String sdkId, String groupId, List<Code> codeBatch) → Future<List<Code>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited