EntityReferencePlatformApi class

Constructors

EntityReferencePlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createEntityReference(String sdkId, EntityReference entityReference) → Future<EntityReference>
getLatest(String sdkId, String prefix) → Future<EntityReference>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited