FormPlatformApi class

Constructors

FormPlatformApi(MethodChannel _methodChannel)

Properties

encrypted ↔ FormEncryptedPlatformApi
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover ↔ FormTryAndRecoverPlatformApi
getter/setter pair

Methods

createDelegationDeAnonymizationMetadata(String sdkId, Form entity, Set<String> delegates) → Future<void>
createForm(String sdkId, DecryptedForm entity) → Future<DecryptedForm>
createForms(String sdkId, List<DecryptedForm> entities) → Future<List<DecryptedForm>>
createFormTemplate(String sdkId, FormTemplate formTemplate) → Future<FormTemplate>
decrypt(String sdkId, EncryptedForm form) → Future<DecryptedForm>
decryptPatientIdOf(String sdkId, Form form) → Future<Set<String>>
deleteForm(String sdkId, Form form) → Future<DocIdentifier>
deleteFormById(String sdkId, String entityId, String rev) → Future<DocIdentifier>
deleteForms(String sdkId, List<Form> forms) → Future<List<DocIdentifier>>
deleteFormsByIds(String sdkId, List<StoredDocumentIdentifier> entityIds) → Future<List<DocIdentifier>>
deleteFormTemplate(String sdkId, String formTemplateId) → Future<DocIdentifier>
filterFormsBy(String sdkId, FilterOptions<Form> filter) → Future<PaginatedListIterator<DecryptedForm>>
filterFormsBySorted(String sdkId, SortableFilterOptions<Form> filter) → Future<PaginatedListIterator<DecryptedForm>>
getEncryptionKeysOf(String sdkId, Form form) → Future<Set<String>>
getForm(String sdkId, String entityId) → Future<DecryptedForm?>
getForms(String sdkId, List<String> entityIds) → Future<List<DecryptedForm>>
getFormTemplate(String sdkId, String formTemplateId, bool? raw) → Future<FormTemplate>
getLatestFormByLogicalUuid(String sdkId, String logicalUuid) → Future<DecryptedForm>
getLatestFormByUniqueId(String sdkId, String uniqueId) → Future<DecryptedForm>
hasWriteAccess(String sdkId, Form form) → Future<bool>
matchFormsBy(String sdkId, FilterOptions<Form> filter) → Future<List<String>>
matchFormsBySorted(String sdkId, SortableFilterOptions<Form> filter) → Future<List<String>>
modifyForm(String sdkId, DecryptedForm entity) → Future<DecryptedForm>
modifyForms(String sdkId, List<DecryptedForm> entities) → Future<List<DecryptedForm>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeForm(String sdkId, Form form) → Future<void>
purgeFormById(String sdkId, String id, String rev) → Future<void>
setTemplateAttachment(String sdkId, String formTemplateId, Uint8List payload) → Future<String>
shareWith(String sdkId, String delegateId, DecryptedForm form, FormShareOptions? options) → Future<DecryptedForm>
shareWithMany(String sdkId, DecryptedForm form, Map<String, FormShareOptions> delegates) → Future<DecryptedForm>
toString() → String
A string representation of this object.
inherited
tryDecrypt(String sdkId, EncryptedForm form) → Future<Form>
undeleteForm(String sdkId, Form form) → Future<DecryptedForm>
undeleteFormById(String sdkId, String id, String rev) → Future<DecryptedForm>
updateFormTemplate(String sdkId, FormTemplate formTemplate) → Future<FormTemplate>
withEncryptionMetadata(String sdkId, DecryptedForm? base, Patient patient, User? user, Map<String, AccessLevel> delegates, SecretIdUseOption secretId) → Future<DecryptedForm>

Operators

operator ==(Object other) → bool
The equality operator.
inherited