FormTryAndRecoverPlatformApi class

Constructors

FormTryAndRecoverPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createForm(String sdkId, Form entity) → Future<Form>
createForms(String sdkId, List<Form> entities) → Future<List<Form>>
filterFormsBy(String sdkId, FilterOptions<Form> filter) → Future<PaginatedListIterator<Form>>
filterFormsBySorted(String sdkId, SortableFilterOptions<Form> filter) → Future<PaginatedListIterator<Form>>
getForm(String sdkId, String entityId) → Future<Form?>
getForms(String sdkId, List<String> entityIds) → Future<List<Form>>
getLatestFormByLogicalUuid(String sdkId, String logicalUuid) → Future<Form>
getLatestFormByUniqueId(String sdkId, String uniqueId) → Future<Form>
modifyForm(String sdkId, Form entity) → Future<Form>
modifyForms(String sdkId, List<Form> entities) → Future<List<Form>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String sdkId, String delegateId, Form form, FormShareOptions? options) → Future<Form>
shareWithMany(String sdkId, Form form, Map<String, FormShareOptions> delegates) → Future<Form>
toString() → String
A string representation of this object.
inherited
undeleteForm(String sdkId, Form form) → Future<Form>
undeleteFormById(String sdkId, String id, String rev) → Future<Form>

Operators

operator ==(Object other) → bool
The equality operator.
inherited