HealthElementInGroupPlatformApi class

Constructors

HealthElementInGroupPlatformApi(MethodChannel _methodChannel)

Properties

encrypted ↔ HealthElementInGroupEncryptedPlatformApi
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover ↔ HealthElementInGroupTryAndRecoverPlatformApi
getter/setter pair

Methods

createDelegationDeAnonymizationMetadata(String sdkId, GroupScoped<HealthElement> entity, Set<EntityReferenceInGroup> delegates) → Future<void>
createHealthElement(String sdkId, GroupScoped<DecryptedHealthElement> entity) → Future<GroupScoped<DecryptedHealthElement>>
decrypt(String sdkId, List<GroupScoped<EncryptedHealthElement>> healthElements) → Future<List<GroupScoped<DecryptedHealthElement>>>
decryptPatientIdOf(String sdkId, GroupScoped<HealthElement> healthElement) → Future<Set<EntityReferenceInGroup>>
encryptOrValidate(String sdkId, List<GroupScoped<HealthElement>> healthElements) → Future<List<GroupScoped<EncryptedHealthElement>>>
getEncryptionKeysOf(String sdkId, GroupScoped<HealthElement> healthElement) → Future<Set<String>>
getHealthElement(String sdkId, String groupId, String entityId) → Future<GroupScoped<DecryptedHealthElement>?>
hasWriteAccess(String sdkId, GroupScoped<HealthElement> healthElement) → Future<bool>
modifyHealthElement(String sdkId, GroupScoped<DecryptedHealthElement> entity) → Future<GroupScoped<DecryptedHealthElement>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String sdkId, EntityReferenceInGroup delegate, GroupScoped<DecryptedHealthElement> healthElement, HealthElementShareOptions? options) → Future<GroupScoped<DecryptedHealthElement>>
shareWithMany(String sdkId, GroupScoped<DecryptedHealthElement> healthElement, Map<EntityReferenceInGroup, HealthElementShareOptions> delegates) → Future<GroupScoped<DecryptedHealthElement>>
toString() → String
A string representation of this object.
inherited
tryDecrypt(String sdkId, List<GroupScoped<EncryptedHealthElement>> healthElements) → Future<List<GroupScoped<HealthElement>>>
withEncryptionMetadata(String sdkId, String entityGroupId, DecryptedHealthElement? base, GroupScoped<Patient> patient, User? user, Map<EntityReferenceInGroup, AccessLevel> delegates, SecretIdUseOption secretId) → Future<GroupScoped<DecryptedHealthElement>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited