HealthElementInGroupTryAndRecoverPlatformApi class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createHealthElement(String sdkId, GroupScoped<HealthElement> entity) → Future<GroupScoped<HealthElement>>
getHealthElement(String sdkId, String groupId, String entityId) → Future<GroupScoped<HealthElement>?>
modifyHealthElement(String sdkId, GroupScoped<HealthElement> entity) → Future<GroupScoped<HealthElement>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String sdkId, EntityReferenceInGroup delegate, GroupScoped<HealthElement> healthElement, HealthElementShareOptions? options) → Future<GroupScoped<HealthElement>>
shareWithMany(String sdkId, GroupScoped<HealthElement> healthElement, Map<EntityReferenceInGroup, HealthElementShareOptions> delegates) → Future<GroupScoped<HealthElement>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited