HealthElementPlatformApi class

Constructors

HealthElementPlatformApi(MethodChannel _methodChannel)

Properties

encrypted ↔ HealthElementEncryptedPlatformApi
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inGroup ↔ HealthElementInGroupPlatformApi
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover ↔ HealthElementTryAndRecoverPlatformApi
getter/setter pair

Methods

createDelegationDeAnonymizationMetadata(String sdkId, HealthElement entity, Set<String> delegates) → Future<void>
createHealthElement(String sdkId, DecryptedHealthElement entity) → Future<DecryptedHealthElement>
createHealthElements(String sdkId, List<DecryptedHealthElement> entities) → Future<List<DecryptedHealthElement>>
decrypt(String sdkId, List<EncryptedHealthElement> healthElements) → Future<List<DecryptedHealthElement>>
decryptPatientIdOf(String sdkId, HealthElement healthElement) → Future<Set<EntityReferenceInGroup>>
deleteHealthElement(String sdkId, HealthElement healthElement) → Future<StoredDocumentIdentifier>
deleteHealthElementById(String sdkId, String entityId, String rev) → Future<StoredDocumentIdentifier>
deleteHealthElements(String sdkId, List<HealthElement> healthElements) → Future<List<StoredDocumentIdentifier>>
deleteHealthElementsByIds(String sdkId, List<StoredDocumentIdentifier> entityIds) → Future<List<StoredDocumentIdentifier>>
encryptOrValidate(String sdkId, List<HealthElement> healthElements) → Future<List<EncryptedHealthElement>>
filterHealthElementsBy(String sdkId, FilterOptions<HealthElement> filter) → Future<PaginatedListIterator<DecryptedHealthElement>>
filterHealthElementsBySorted(String sdkId, SortableFilterOptions<HealthElement> filter) → Future<PaginatedListIterator<DecryptedHealthElement>>
getEncryptionKeysOf(String sdkId, HealthElement healthElement) → Future<Set<String>>
getHealthElement(String sdkId, String entityId) → Future<DecryptedHealthElement?>
getHealthElements(String sdkId, List<String> entityIds) → Future<List<DecryptedHealthElement>>
hasWriteAccess(String sdkId, HealthElement healthElement) → Future<bool>
matchHealthElementsBy(String sdkId, FilterOptions<HealthElement> filter) → Future<List<String>>
matchHealthElementsBySorted(String sdkId, SortableFilterOptions<HealthElement> filter) → Future<List<String>>
modifyHealthElement(String sdkId, DecryptedHealthElement entity) → Future<DecryptedHealthElement>
modifyHealthElements(String sdkId, List<DecryptedHealthElement> entities) → Future<List<DecryptedHealthElement>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeHealthElement(String sdkId, HealthElement healthElement) → Future<void>
purgeHealthElementById(String sdkId, String id, String rev) → Future<void>
shareWith(String sdkId, String delegateId, DecryptedHealthElement healthElement, HealthElementShareOptions? options) → Future<DecryptedHealthElement>
shareWithMany(String sdkId, DecryptedHealthElement healthElement, Map<String, HealthElementShareOptions> delegates) → Future<DecryptedHealthElement>
subscribeToEvents(String sdkId, Set<SubscriptionEventType> events, FilterOptions<HealthElement> filter, EntitySubscriptionConfiguration? subscriptionConfig) → Future<EntitySubscription<EncryptedHealthElement>>
toString() → String
A string representation of this object.
inherited
tryDecrypt(String sdkId, List<EncryptedHealthElement> healthElements) → Future<List<HealthElement>>
undeleteHealthElement(String sdkId, HealthElement healthElement) → Future<DecryptedHealthElement>
undeleteHealthElementById(String sdkId, String id, String rev) → Future<DecryptedHealthElement>
withEncryptionMetadata(String sdkId, DecryptedHealthElement? base, Patient patient, User? user, Map<String, AccessLevel> delegates, SecretIdUseOption secretId) → Future<DecryptedHealthElement>

Operators

operator ==(Object other) → bool
The equality operator.
inherited