InsurancePlatformApi class

Constructors

InsurancePlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createInsurance(String sdkId, Insurance insurance) → Future<Insurance>
deleteInsurance(String sdkId, String insuranceId) → Future<DocIdentifier>
getInsurance(String sdkId, String insuranceId) → Future<Insurance?>
getInsurances(String sdkId, List<String> insuranceIds) → Future<List<Insurance>>
listInsurancesByCode(String sdkId, String insuranceCode) → Future<List<Insurance>>
listInsurancesByName(String sdkId, String insuranceName) → Future<List<Insurance>>
modifyInsurance(String sdkId, Insurance insurance) → Future<Insurance>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited