InvoicePlatformApi class

Constructors

InvoicePlatformApi(MethodChannel _methodChannel)

Properties

encrypted ↔ InvoiceEncryptedPlatformApi
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryAndRecover ↔ InvoiceTryAndRecoverPlatformApi
getter/setter pair

Methods

appendCodes(String sdkId, String userId, String type, String sentMediumType, String secretFKeys, String? insuranceId, String? invoiceId, int? gracePeriod, List<EncryptedInvoicingCode> invoicingCodes) → Future<List<DecryptedInvoice>>
createDelegationDeAnonymizationMetadata(String sdkId, Invoice entity, Set<String> delegates) → Future<void>
createInvoice(String sdkId, DecryptedInvoice entity, String? prefix) → Future<DecryptedInvoice>
createInvoices(String sdkId, List<DecryptedInvoice> entities) → Future<List<DecryptedInvoice>>
decrypt(String sdkId, EncryptedInvoice invoice) → Future<DecryptedInvoice>
decryptPatientIdOf(String sdkId, Invoice invoice) → Future<Set<String>>
deleteInvoice(String sdkId, String entityId) → Future<DocIdentifier>
getEncryptionKeysOf(String sdkId, Invoice invoice) → Future<Set<String>>
getInvoice(String sdkId, String entityId) → Future<DecryptedInvoice?>
getInvoices(String sdkId, List<String> entityIds) → Future<List<DecryptedInvoice>>
getTarificationsCodesOccurrences(String sdkId, int minOccurrence) → Future<List<LabelledOccurence>>
hasWriteAccess(String sdkId, Invoice invoice) → Future<bool>
listInvoicesByContactIds(String sdkId, List<String> contactIds) → Future<List<DecryptedInvoice>>
listInvoicesByHcPartyAndGroupId(String sdkId, String hcPartyId, String groupId) → Future<List<DecryptedInvoice>>
listInvoicesByHcpartySendingModeStatusDate(String sdkId, String hcPartyId, String sendingMode, String status, int from, int to) → Future<List<DecryptedInvoice>>
listInvoicesByHcPartySentMediumTypeInvoiceTypeSentDate(String sdkId, String hcPartyId, MediumType sentMediumType, InvoiceType invoiceType, bool sent, int? from, int? to) → Future<List<DecryptedInvoice>>
listInvoicesByIds(String sdkId, List<String> ids) → Future<List<DecryptedInvoice>>
listInvoicesByRecipientsIds(String sdkId, List<String> recipientsIds) → Future<List<DecryptedInvoice>>
listToInsurances(String sdkId, List<String> userIds) → Future<List<DecryptedInvoice>>
listToInsurancesUnsent(String sdkId, List<String> userIds) → Future<List<DecryptedInvoice>>
listToPatients(String sdkId, String hcPartyId) → Future<List<DecryptedInvoice>>
listToPatientsUnsent(String sdkId, String? hcPartyId) → Future<List<DecryptedInvoice>>
mergeTo(String sdkId, String invoiceId, List<String> ids) → Future<DecryptedInvoice>
modifyInvoice(String sdkId, DecryptedInvoice entity) → Future<DecryptedInvoice>
modifyInvoices(String sdkId, List<DecryptedInvoice> entities) → Future<List<DecryptedInvoice>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassignInvoice(String sdkId, DecryptedInvoice invoice) → Future<DecryptedInvoice>
removeCodes(String sdkId, String userId, String serviceId, String secretFKeys, List<String> tarificationIds) → Future<List<DecryptedInvoice>>
shareWith(String sdkId, String delegateId, DecryptedInvoice invoice, InvoiceShareOptions? options) → Future<DecryptedInvoice>
shareWithMany(String sdkId, DecryptedInvoice invoice, Map<String, InvoiceShareOptions> delegates) → Future<DecryptedInvoice>
toString() → String
A string representation of this object.
inherited
tryDecrypt(String sdkId, EncryptedInvoice invoice) → Future<Invoice>
validate(String sdkId, String invoiceId, String scheme, String forcedValue) → Future<DecryptedInvoice>
withEncryptionMetadata(String sdkId, DecryptedInvoice? base, Patient? patient, User? user, Map<String, AccessLevel> delegates, SecretIdUseOption secretId) → Future<DecryptedInvoice>

Operators

operator ==(Object other) → bool
The equality operator.
inherited