KeywordPlatformApi class

Constructors

KeywordPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createKeyword(String sdkId, Keyword keyword) → Future<Keyword>
deleteKeywords(String sdkId, List<String> keywordIds) → Future<List<DocIdentifier>>
getKeyword(String sdkId, String keywordId) → Future<Keyword?>
getKeywordsByUser(String sdkId, String userId) → Future<List<Keyword>>
modifyKeyword(String sdkId, Keyword keyword) → Future<Keyword>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited