MessageTryAndRecoverPlatformApi class

Constructors

MessageTryAndRecoverPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createMessage(String sdkId, Message entity) → Future<Message>
createMessageInTopic(String sdkId, Message entity) → Future<Message>
filterMessagesBy(String sdkId, FilterOptions<Message> filter) → Future<PaginatedListIterator<Message>>
filterMessagesBySorted(String sdkId, SortableFilterOptions<Message> filter) → Future<PaginatedListIterator<Message>>
getMessage(String sdkId, String entityId) → Future<Message?>
getMessages(String sdkId, List<String> entityIds) → Future<List<Message>>
modifyMessage(String sdkId, Message entity) → Future<Message>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMessagesReadStatus(String sdkId, List<String> entityIds, int? time, bool readStatus, String? userId) → Future<List<Message>>
shareWith(String sdkId, String delegateId, Message message, MessageShareOptions? options) → Future<Message>
shareWithMany(String sdkId, Message message, Map<String, MessageShareOptions> delegates) → Future<Message>
toString() → String
A string representation of this object.
inherited
undeleteMessage(String sdkId, Message message) → Future<Message>
undeleteMessageById(String sdkId, String id, String rev) → Future<Message>

Operators

operator ==(Object other) → bool
The equality operator.
inherited