PatientBasicPlatformApi class

Constructors

PatientBasicPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
inGroup ↔ PatientBasicInGroupPlatformApi
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPatient(String sdkId, EncryptedPatient patient) → Future<EncryptedPatient>
createPatients(String sdkId, List<EncryptedPatient> patients) → Future<List<EncryptedPatient>>
createPatientsMinimal(String sdkId, List<EncryptedPatient> patients) → Future<List<StoredDocumentIdentifier>>
deletePatient(String sdkId, Patient patient) → Future<StoredDocumentIdentifier>
deletePatientById(String sdkId, String entityId, String rev) → Future<StoredDocumentIdentifier>
deletePatients(String sdkId, List<Patient> patients) → Future<List<StoredDocumentIdentifier>>
deletePatientsByIds(String sdkId, List<StoredDocumentIdentifier> entityIds) → Future<List<StoredDocumentIdentifier>>
filterPatientsBy(String sdkId, BaseFilterOptions<Patient> filter) → Future<PaginatedListIterator<EncryptedPatient>>
filterPatientsBySorted(String sdkId, BaseSortableFilterOptions<Patient> filter) → Future<PaginatedListIterator<EncryptedPatient>>
getDataOwnersWithAccessTo(String sdkId, Patient patient) → Future<EntityAccessInformation>
getPatient(String sdkId, String entityId) → Future<EncryptedPatient?>
getPatientResolvingMerges(String sdkId, String patientId, int? maxMergeDepth) → Future<EncryptedPatient>
getPatients(String sdkId, List<String> patientIds) → Future<List<EncryptedPatient>>
matchPatientsBy(String sdkId, BaseFilterOptions<Patient> filter) → Future<List<String>>
matchPatientsBySorted(String sdkId, BaseSortableFilterOptions<Patient> filter) → Future<List<String>>
mergePatients(String sdkId, Patient from, EncryptedPatient mergedInto) → Future<EncryptedPatient>
modifyPatient(String sdkId, EncryptedPatient entity) → Future<EncryptedPatient>
modifyPatients(String sdkId, List<EncryptedPatient> patients) → Future<List<EncryptedPatient>>
modifyPatientsMinimal(String sdkId, List<EncryptedPatient> patients) → Future<List<StoredDocumentIdentifier>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgePatient(String sdkId, Patient patient) → Future<void>
purgePatientById(String sdkId, String id, String rev) → Future<void>
subscribeToEvents(String sdkId, Set<SubscriptionEventType> events, BaseFilterOptions<Patient> filter, EntitySubscriptionConfiguration? subscriptionConfig) → Future<EntitySubscription<EncryptedPatient>>
toString() → String
A string representation of this object.
inherited
undeletePatient(String sdkId, Patient patient) → Future<Patient>
undeletePatientById(String sdkId, String id, String rev) → Future<EncryptedPatient>
undeletePatients(String sdkId, List<StoredDocumentIdentifier> ids) → Future<List<EncryptedPatient>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited