PatientTryAndRecoverPlatformApi class

Constructors

PatientTryAndRecoverPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPatient(String sdkId, Patient patient) → Future<Patient>
createPatients(String sdkId, List<Patient> patients) → Future<List<Patient>>
createPatientsMinimal(String sdkId, List<Patient> patients) → Future<List<StoredDocumentIdentifier>>
filterPatientsBy(String sdkId, FilterOptions<Patient> filter) → Future<PaginatedListIterator<Patient>>
filterPatientsBySorted(String sdkId, SortableFilterOptions<Patient> filter) → Future<PaginatedListIterator<Patient>>
getPatient(String sdkId, String entityId) → Future<Patient?>
getPatientResolvingMerges(String sdkId, String patientId, int? maxMergeDepth) → Future<Patient>
getPatients(String sdkId, List<String> patientIds) → Future<List<Patient>>
initializeConfidentialSecretId(String sdkId, Patient patient) → Future<Patient>
mergePatients(String sdkId, Patient from, Patient mergedInto) → Future<Patient>
modifyPatient(String sdkId, Patient entity) → Future<Patient>
modifyPatients(String sdkId, List<Patient> patients) → Future<List<Patient>>
modifyPatientsMinimal(String sdkId, List<Patient> patients) → Future<List<StoredDocumentIdentifier>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String sdkId, String delegateId, Patient patient, PatientShareOptions? options) → Future<Patient>
shareWithMany(String sdkId, Patient patient, Map<String, PatientShareOptions> delegates) → Future<Patient>
toString() → String
A string representation of this object.
inherited
undeletePatient(String sdkId, Patient patient) → Future<Patient>
undeletePatientById(String sdkId, String id, String rev) → Future<Patient>
undeletePatients(String sdkId, List<StoredDocumentIdentifier> ids) → Future<List<Patient>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited