PlacePlatformApi class

Constructors

PlacePlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPlace(String sdkId, Place place) → Future<Place>
deletePlaces(String sdkId, List<String> placeIds) → Future<List<DocIdentifier>>
getPlace(String sdkId, String placeId) → Future<Place?>
modifyPlace(String sdkId, Place place) → Future<Place>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited