ReceiptTryAndRecoverPlatformApi class

Constructors

ReceiptTryAndRecoverPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createReceipt(String sdkId, Receipt entity) → Future<Receipt>
getReceipt(String sdkId, String entityId) → Future<Receipt?>
listByReference(String sdkId, String reference) → Future<List<Receipt>>
modifyReceipt(String sdkId, Receipt entity) → Future<Receipt>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shareWith(String sdkId, String delegateId, Receipt receipt, ReceiptShareOptions? options) → Future<Receipt>
shareWithMany(String sdkId, Receipt receipt, Map<String, ReceiptShareOptions> delegates) → Future<Receipt>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited