SystemPlatformApi class

Constructors

SystemPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

evictAllFromMap(String sdkId, String mapName) → Future<String>
getIndexingInfo(String sdkId) → Future<IndexingInfo>
getIndexingInfoByGroup(String sdkId, String groupId) → Future<IndexingInfo>
getProcessInfo(String sdkId) → Future<String>
getReplicationInfo(String sdkId) → Future<ReplicationInfo>
getReplicatorInfo(String sdkId, String id) → Future<ReplicatorDocument>
getVersion(String sdkId) → Future<String>
isReady(String sdkId) → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveContactsConflicts(String sdkId, int? limit) → Future<List<IdWithRev>>
resolveDocumentsConflicts(String sdkId, String? ids, int? limit) → Future<List<IdWithRev>>
resolveFormsConflicts(String sdkId, int? limit) → Future<List<IdWithRev>>
resolveHealthElementsConflicts(String sdkId, int? limit) → Future<List<IdWithRev>>
resolveInvoicesConflicts(String sdkId, int? limit) → Future<List<IdWithRev>>
resolveMessagesConflicts(String sdkId, int? limit) → Future<List<IdWithRev>>
resolvePatientsConflicts(String sdkId, int? limit) → Future<List<IdWithRev>>
toString() → String
A string representation of this object.
inherited
updateDesignDoc(String sdkId, String entityName, bool? warmup) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited