TarificationPlatformApi class

Constructors

TarificationPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTarification(String sdkId, Tarification tarification) → Future<Tarification>
getTarification(String sdkId, String tarificationId) → Future<Tarification?>
getTarifications(String sdkId, List<String> tarificationIds) → Future<List<Tarification>>
getTarificationWithParts(String sdkId, String type, String tarification, String version) → Future<Tarification>
modifyTarification(String sdkId, Tarification tarification) → Future<Tarification>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited