TopicEncryptedPlatformApi class

Constructors

TopicEncryptedPlatformApi(MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addParticipant(String sdkId, String entityId, String dataOwnerId, TopicRole topicRole) → Future<EncryptedTopic>
createTopic(String sdkId, EncryptedTopic entity) → Future<EncryptedTopic>
filterTopicsBy(String sdkId, FilterOptions<Topic> filter) → Future<PaginatedListIterator<EncryptedTopic>>
filterTopicsBySorted(String sdkId, SortableFilterOptions<Topic> filter) → Future<PaginatedListIterator<EncryptedTopic>>
getTopic(String sdkId, String entityId) → Future<EncryptedTopic?>
getTopics(String sdkId, List<String> entityIds) → Future<List<EncryptedTopic>>
modifyTopic(String sdkId, EncryptedTopic entity) → Future<EncryptedTopic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeParticipant(String sdkId, String entityId, String dataOwnerId) → Future<EncryptedTopic>
shareWith(String sdkId, String delegateId, EncryptedTopic topic, TopicShareOptions? options) → Future<EncryptedTopic>
shareWithMany(String sdkId, EncryptedTopic topic, Map<String, TopicShareOptions> delegates) → Future<EncryptedTopic>
toString() → String
A string representation of this object.
inherited
undeleteTopic(String sdkId, Topic topic) → Future<Topic>
undeleteTopicById(String sdkId, String id, String rev) → Future<EncryptedTopic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited