CardinalSdkInitializersPlugin class abstract

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

baseSwitchGroup(String sdkId, String groupId) → Future<CardinalBaseSdk>
completeAuthentication(String authenticationStepId, String validationCode) → Future<CardinalSdk>
initialize(String? applicationId, String baseUrl, AuthenticationMethod authenticationMethod, StorageOptions storageOptions, SdkOptions options) → Future<CardinalSdk>
initializeBase(String? applicationId, String baseUrl, AuthenticationMethod authenticationMethod, BasicSdkOptions options) → Future<CardinalBaseSdk>
initializeWithProcess(String? applicationId, String baseUrl, String messageGatewayUrl, String externalServicesSpecId, String processId, AuthenticationProcessTelecomType userTelecomType, String userTelecom, CaptchaOptions captcha, StorageOptions storageOptions, AuthenticationProcessTemplateParameters authenticationProcessTemplateParameters, SdkOptions options) → Future<AuthenticationWithProcessStep>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchGroup(String sdkId, String groupId) → Future<CardinalSdk>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited