CardinalSdkMethodChannelInterface class

Inheritance

Properties

apis → CardinalSdkPlatformApisPlugin
no setteroverride
crypto → CardinalSdkPlatformCryptoPlugin
no setteroverride
filters → CardinalSdkPlatformFiltersPlugin
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
initializers → CardinalSdkInitializersPlugin
no setteroverride
pagination → CardinalSdkPlatformPaginationPlugin
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → CardinalSdkPlatformSubscriptionPlugin
no setteroverride
utils → CardinalSdkPlatformUtilsPlugin
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited