CardinalSdkPlatformInterface class

Inheritance
  • Object
  • PlatformInterface
  • CardinalSdkPlatformInterface
Implementers

Properties

apis → CardinalSdkPlatformApisPlugin
no setter
crypto → CardinalSdkPlatformCryptoPlugin
no setter
filters → CardinalSdkPlatformFiltersPlugin
no setter
hashCode → int
The hash code for this object.
no setterinherited
initializers → CardinalSdkInitializersPlugin
no setter
pagination → CardinalSdkPlatformPaginationPlugin
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → CardinalSdkPlatformSubscriptionPlugin
no setter
utils → CardinalSdkPlatformUtilsPlugin
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CardinalSdkPlatformInterface
getter/setter pair