CardinalSdkMethodChannelSubscription class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close(String subscriptionId) → Future<void>
override
getCloseReason(String subscriptionId) → Future<EntitySubscriptionCloseReason?>
override
getEvent(String subscriptionId) → Future<Map<String, dynamic>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitForEvent(String subscriptionId, Duration timeout, int cancellationToken) → Future<Map<String, dynamic>?>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited