CardinalSdkPlatformSubscriptionPlugin class abstract

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close(String sdkId) → Future<void>
getCloseReason(String sdkId) → Future<EntitySubscriptionCloseReason?>
getEvent(String sdkId) → Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitForEvent(String sdkId, Duration timeout, int cancellationToken) → Future<Map<String, dynamic>?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited