EntitySubscription<T extends Identifiable<String>> class

Constructors

EntitySubscription(String instanceId, T decodeT(Map<String, dynamic>))
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
getCloseReason() → Future<EntitySubscriptionCloseReason?>
getEvent() → Future<EntitySubscriptionEvent<T>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitForEvent(Duration timeout) → CancellableFuture<EntitySubscriptionEvent<T>?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited