EntitySubscriptionConfiguration class abstract

Annotations
  • @freezed

Constructors

EntitySubscriptionConfiguration({@Default.new(100) int channelBufferCapacity, @Default.new(EntitySubscriptionConfigurationFullBufferBehaviour.close) EntitySubscriptionConfigurationFullBufferBehaviour onBufferFull, @Default.new(Duration(seconds: 2)) Duration reconnectionDelay, @Default.new(2.0) double retryDelayExponentFactor, @Default.new(5) int connectionMaxRetries})
const
factory

Properties

channelBufferCapacity → int
no setterinherited
connectionMaxRetries → int
no setterinherited
copyWith → $EntitySubscriptionConfigurationCopyWith<EntitySubscriptionConfiguration>
Create a copy of EntitySubscriptionConfiguration with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
onBufferFull → EntitySubscriptionConfigurationFullBufferBehaviour
no setterinherited
reconnectionDelay → Duration
no setterinherited
retryDelayExponentFactor → double
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(EntitySubscriptionConfiguration value) → Map<String, dynamic>
fromJSON(Map<String, dynamic> data) → EntitySubscriptionConfiguration